"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QQmlComponent(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlcomponent.html

    **Detailed Description**

    Components are reusable, encapsulated QML types with well-defined
    interfaces.

    A QQmlComponent instance can be created from a QML file. For example, if
    there is a `main.qml` file like this:

    import QtQuick 2.0

        **Item**  {
            width: 200
            height:
    200
        }

    The following code loads this QML file as a component, creates an instance
    of this component using **create** (), and then queries the **Item** 's
    **width**  value:

    **QQmlEngine**  *engine = new **QQmlEngine** ;
        QQmlComponent
    component(engine, **QUrl** ::fromLocalFile("main.qml"));
    **QObject**  *myObject = component.create();
        **QQuickItem**  *item =
    qobject_cast<**QQuickItem** *>(myObject);
        int width = item->width();  //
    width = 200

    To create instances of a component in code where a **QQmlEngine**  instance
    is not available, you can use **qmlContext** () or **qmlEngine** (). For
    example, in the scenario below, child items are being created within a
    **QQuickItem**  subclass:

    void MyCppItem::init()
        {
            **QQmlEngine**  *engine =
    qmlEngine(this);
            // Or:
            // QQmlEngine *engine =
    qmlContext(this)->engine();
            QQmlComponent component(engine, **QUrl**
    ::fromLocalFile("MyItem.qml"));
            **QQuickItem**  *childItem =
    qobject_cast<**QQuickItem** *>(component.create());
    childItem->setParentItem(this);
        }

    Note that these functions will return `null` when called inside the
    constructor of a **QObject**  subclass, as the instance will not yet have a
    context nor engine.

    **Network Components**

    If the URL passed to QQmlComponent is a network resource, or if the QML
    document references a network resource, the QQmlComponent has to fetch the
    network data before it is able to create objects. In this case, the
    QQmlComponent will have a **Loading**  **status** . An application will have
    to wait until the component is **Ready**  before calling
    **QQmlComponent::create** ().

    The following example shows how to load a QML file from a network resource.
    After creating the QQmlComponent, it tests whether the component is loading.
    If it is, it connects to the **QQmlComponent::statusChanged** () signal and
    otherwise calls the `continueLoading()` method directly. Note that
    **QQmlComponent::isLoading** () may be false for a network component if the
    component has been cached and is ready immediately.

    MyApplication::MyApplication()
        {
            // ...
            component = new
    QQmlComponent(engine, **QUrl** ("http://www.example.com/main.qml"));
    if (component->isLoading()) {
                **QObject** ::connect(component,
    &QQmlComponent::statusChanged,
                                 this,
    &MyApplication::continueLoading);
            } else {
    continueLoading();
            }
        }

        void
    MyApplication::continueLoading()
        {
            if (component->isError()) {
    **qWarning** () << component->errors();
            } else {
    **QObject**  *myObject = component->create();
            }
        }
    """

    class Status(enum.Enum):
        Null: QQmlComponent = ...
        Ready: QQmlComponent = ...
        Loading: QQmlComponent = ...
        Error: QQmlComponent = ...

    class CompilationMode(enum.Enum):
        PreferSynchronous: QQmlComponent = ...
        Asynchronous: QQmlComponent = ...

    @typing.overload
    def __init__(
        self, a0: QQmlEngine, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#QQmlComponent-1

        **QQmlComponent::QQmlComponent(QQmlEngine * engine , QObject * parent =
        nullptr)**

        Create a QQmlComponent with no data and give it the specified **engine**
        and **parent**. Set the data with **setData** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: QQmlEngine,
        fileName: str,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#QQmlComponent-2

        **QQmlComponent::QQmlComponent(QQmlEngine * engine , const QString &
        fileName , QObject * parent = nullptr)**

        Create a QQmlComponent from the given **fileName** and give it the
        specified **parent** and **engine**.

        **See also** **loadUrl** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: QQmlEngine,
        fileName: str,
        mode: "QQmlComponent.CompilationMode",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#QQmlComponent-3

        **QQmlComponent::QQmlComponent(QQmlEngine * engine , const QString &
        fileName , QQmlComponent::CompilationMode mode , QObject * parent =
        nullptr)**

        Create a QQmlComponent from the given **fileName** and give it the
        specified **parent** and **engine**. If **mode** is **Asynchronous** ,
        the component will be loaded and compiled asynchronously.

        **See also** **loadUrl** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: QQmlEngine,
        url: QtCore.QUrl,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#QQmlComponent-4

        **QQmlComponent::QQmlComponent(QQmlEngine * engine , const QUrl & url ,
        QObject * parent = nullptr)**

        Create a QQmlComponent from the given **url** and give it the specified
        **parent** and **engine**.

        Ensure that the URL provided is full and correct, in particular, use
        **QUrl::fromLocalFile** () when loading a file from the local
        filesystem.

        Relative paths will be resolved against **QQmlEngine::baseUrl** (),
        which is the current working directory unless specified.

        **See also** **loadUrl** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: QQmlEngine,
        url: QtCore.QUrl,
        mode: "QQmlComponent.CompilationMode",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#QQmlComponent-5

        **QQmlComponent::QQmlComponent(QQmlEngine * engine , const QUrl & url ,
        QQmlComponent::CompilationMode mode , QObject * parent = nullptr)**

        Create a QQmlComponent from the given **url** and give it the specified
        **parent** and **engine**. If **mode** is **Asynchronous** , the
        component will be loaded and compiled asynchronously.

        Ensure that the URL provided is full and correct, in particular, use
        **QUrl::fromLocalFile** () when loading a file from the local
        filesystem.

        Relative paths will be resolved against **QQmlEngine::baseUrl** (),
        which is the current working directory unless specified.

        **See also** **loadUrl** ().
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#QQmlComponent-1

        **QQmlComponent::QQmlComponent(QQmlEngine * engine , QObject * parent =
        nullptr)**

        Create a QQmlComponent with no data and give it the specified **engine**
        and **parent**. Set the data with **setData** ().
        """
        ...

    def setInitialProperties(
        self, component: QtCore.QObject, properties: typing.Dict[str, typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#setInitialProperties

        **[since 5.14] void QQmlComponent::setInitialProperties(QObject *
        component , const QVariantMap & properties )**

        Set top-level **properties** of the **component**.

        This method provides advanced control over component instance creation.
        In general, programmers should use
        **QQmlComponent::createWithInitialProperties**  to create a component.

        Use this method after **beginCreate**  and before **completeCreate**
        has been called. If a provided property does not exist, a warning is
        issued.

        This function was introduced in Qt 5.14.
        """
        ...

    def engine(self) -> QQmlEngine:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#engine

        **[since 5.12] QQmlEngine *QQmlComponent::engine() const**

        Returns the **QQmlEngine**  of this component.

        This function was introduced in Qt 5.12.
        """
        ...

    def setData(self, a0: QtCore.QByteArray, baseUrl: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#setData

        **[slot] void QQmlComponent::setData(const QByteArray & data , const
        QUrl & url )**

        Sets the **QQmlComponent**  to use the given QML **data**. If **url** is
        provided, it is used to set the component name and to provide a base
        path for items resolved by this component.
        """
        ...

    @typing.overload
    def loadUrl(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#loadUrl

        **[slot] void QQmlComponent::loadUrl(const QUrl & url )**

        Load the **QQmlComponent**  from the provided **url**.

        Ensure that the URL provided is full and correct, in particular, use
        **QUrl::fromLocalFile** () when loading a file from the local
        filesystem.

        Relative paths will be resolved against **QQmlEngine::baseUrl** (),
        which is the current working directory unless specified.
        """
        ...

    @typing.overload
    def loadUrl(self, url: QtCore.QUrl, mode: "QQmlComponent.CompilationMode") -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#loadUrl-1

        **[slot] void QQmlComponent::loadUrl(const QUrl & url ,
        QQmlComponent::CompilationMode mode )**

        Load the **QQmlComponent**  from the provided **url**. If **mode** is
        **Asynchronous** , the component will be loaded and compiled
        asynchronously.

        Ensure that the URL provided is full and correct, in particular, use
        **QUrl::fromLocalFile** () when loading a file from the local
        filesystem.

        Relative paths will be resolved against **QQmlEngine::baseUrl** (),
        which is the current working directory unless specified.
        """
        ...

    def creationContext(self) -> "QQmlContext":
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#creationContext

        **QQmlContext *QQmlComponent::creationContext() const**

        Returns the **QQmlContext**  the component was created in. This is only
        valid for components created directly from QML.
        """
        ...

    def completeCreate(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#completeCreate

        **[virtual] void QQmlComponent::completeCreate()**

        This method provides advanced control over component instance creation.
        In general, programmers should use **QQmlComponent::create** () to
        create a component.

        This function completes the component creation begun with
        **QQmlComponent::beginCreate** () and must be called afterwards.

        **See also** **beginCreate** ().
        """
        ...

    def beginCreate(self, a0: "QQmlContext") -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#beginCreate

        **[virtual] QObject *QQmlComponent::beginCreate(QQmlContext * context
        )**

        Create an object instance from this component, within the specified
        **context**. Returns `nullptr` if creation failed.

        **Note:** This method provides advanced control over component instance
        creation. In general, programmers should use **QQmlComponent::create**
        () to create object instances.

        When **QQmlComponent**  constructs an instance, it occurs in three
        steps:

        1. The object hierarchy is created, and constant values are assigned.
        2. Property bindings are evaluated for the first time.
          3. If
        applicable, **QQmlParserStatus::componentComplete** () is called on
        objects.

        QQmlComponent::beginCreate() differs from **QQmlComponent::create** ()
        in that it only performs step 1. **QQmlComponent::completeCreate** ()
        must be called to complete steps 2 and 3.

        This breaking point is sometimes useful when using attached properties
        to communicate information to an instantiated component, as it allows
        their initial values to be configured before property bindings take
        effect.

        The ownership of the returned object instance is transferred to the
        caller.

        **See also** **completeCreate** () and **QQmlEngine::ObjectOwnership** .
        """
        ...

    def createWithInitialProperties(
        self,
        initialProperties: typing.Dict[str, typing.Any],
        context: typing.Optional["QQmlContext"] = ...,
    ) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#createWithInitialProperties

        **[since 5.14] QObject *QQmlComponent::createWithInitialProperties(const
        QVariantMap & initialProperties , QQmlContext * context = nullptr)**

        Create an object instance of this component, within the specified
        **context** , and initialize its top-level properties with
        **initialProperties**.

        If any of the `initialProperties` cannot be set, **isError** () will
        return `true`, and the **errors** () function can be used to get
        detailed information about the error(s).

        This function was introduced in Qt 5.14.

        **See also** **QQmlComponent::create** .
        """
        ...

    @typing.overload
    def create(self, context: typing.Optional["QQmlContext"] = ...) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#create

        **[virtual] QObject *QQmlComponent::create(QQmlContext * context =
        nullptr)**

        Create an object instance from this component, within the specified
        **context**. Returns `nullptr` if creation failed.

        If **context** is `nullptr` (the default), it will create the instance
        in the **root context**  of the engine.

        The ownership of the returned object instance is transferred to the
        caller.

        If the object being created from this component is a visual item, it
        must have a visual parent, which can be set by calling
        **QQuickItem::setParentItem** (). See **Concepts - Visual Parent in Qt
        Quick**  for more details.

        **See also** **QQmlEngine::ObjectOwnership** .
        """
        ...

    @typing.overload
    def create(
        self,
        a0: "QQmlIncubator",
        context: typing.Optional["QQmlContext"] = ...,
        forContext: typing.Optional["QQmlContext"] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#create-1

        **void QQmlComponent::create(QQmlIncubator & incubator , QQmlContext *
        context = nullptr, QQmlContext * forContext = nullptr)**

        Create an object instance from this component using the provided
        **incubator**. **context** specifies the context within which to create
        the object instance.

        If **context** is `nullptr` (by default), it will create the instance in
        the engine's **root context** .

        **forContext** specifies a context that this object creation depends
        upon. If the **forContext** is being created asynchronously, and the
        **QQmlIncubator::IncubationMode**  is
        **QQmlIncubator::AsynchronousIfNested** , this object will also be
        created asynchronously. If **forContext** is `nullptr` (by default), the
        **context** will be used for this decision.

        The created object and its creation status are available via the
        **incubator**.

        **See also** **QQmlIncubator** .
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#url-prop

        **[read-only] url : const QUrl**

        The component URL. This is the URL passed to either the constructor, or
        the **loadUrl** (), or **setData** () methods.

        **Access functions:**

        QUrl **url** () const

        **Member Function Documentation**
        """
        ...

    def progress(self) -> float:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#progress-prop

        **[read-only] progress : const qreal**

        The progress of loading the component, from 0.0 (nothing loaded) to 1.0
        (finished).

        **Access functions:**

        qreal **progress** () const

        **Notifier signal:**

        void ****progressChanged** ** (qreal **progress** )
        """
        ...

    def errors(self) -> typing.List["QQmlError"]:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#errors

        **QList<QQmlError> QQmlComponent::errors() const**

        Returns the list of errors that occurred during the last compile or
        create operation. An empty list is returned if **isError** () is not
        set.
        """
        ...

    def isLoading(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#isLoading

        **bool QQmlComponent::isLoading() const**

        Returns true if **status** () == **QQmlComponent::Loading** .
        """
        ...

    def isError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#isError

        **bool QQmlComponent::isError() const**

        Returns true if **status** () == **QQmlComponent::Error** .
        """
        ...

    def isReady(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#isReady

        **bool QQmlComponent::isReady() const**

        Returns true if **status** () == **QQmlComponent::Ready** .
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#isNull

        **bool QQmlComponent::isNull() const**

        Returns true if **status** () == **QQmlComponent::Null** .
        """
        ...

    def status(self) -> "QQmlComponent.Status":
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#status-prop

        **[read-only] status : const Status**

        The component's current **status** .

        **Access functions:**

        QQmlComponent::Status **status** () const

        **Notifier signal:**

        void ****statusChanged** ** (QQmlComponent::Status **status** )
        """
        ...

    @property
    def progressChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#progressChanged

        **[signal] void QQmlComponent::progressChanged(qreal progress )**

        Emitted whenever the component's loading progress changes. **progress**
        will be the current progress between 0.0 (nothing loaded) and 1.0
        (finished).

        **Note:** Notifier signal for property **progress** .
        """
        ...

    @property
    def statusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlcomponent.html#statusChanged

        **[signal] void QQmlComponent::statusChanged(QQmlComponent::Status
        status )**

        Emitted whenever the component's status changes. **status** will be the
        new status.

        **Note:** Notifier signal for property **status** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets


class QHelpIndexWidget(QtWidgets.QListView):
    """
    https://doc.qt.io/qt-6/qhelpindexwidget.html

    **Detailed Description**
    """

    def activateCurrentItem(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#activateCurrentItem

        **[slot] void QHelpIndexWidget::activateCurrentItem()**

        Activates the current item which will result eventually in the emitting
        of a linkActivated() or linksActivated() signal.
        """
        ...

    def filterIndices(self, filter: str, wildcard: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#filterIndices

        **[slot] void QHelpIndexWidget::filterIndices(const QString & filter ,
        const QString & wildcard = QString())**

        Filters the indices according to **filter** or **wildcard**. The item
        with the best match is set as current item.

        **See also** **QHelpIndexModel::filter** ().
        """
        ...

    @property
    def documentActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#documentActivated

        **[signal, since 5.15] void QHelpIndexWidget::documentActivated(const
        QHelpLink & document , const QString & keyword )**

        This signal is emitted when an item is activated and its associated
        **document** should be shown. To know where the link belongs to, the
        **keyword** is given as a second parameter.

        This function was introduced in Qt 5.15.
        """
        ...

    @property
    def documentsActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#documentsActivated

        **[signal, since 5.15] void QHelpIndexWidget::documentsActivated(const
        QList<QHelpLink> & documents , const QString & keyword )**

        This signal is emitted when the item representing the **keyword** is
        activated and the item has more than one document associated. The
        **documents** consist of the document titles and their URLs.

        This function was introduced in Qt 5.15.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QPageRanges(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpageranges.html

    **Detailed Description**

    Use **QPagedPaintDevice::pageRanges** () to access the collection of page
    ranges associated with a paged device.
    """

    class Range(PyQt6.sip.simplewrapper):
        from_: int = ...
        to: int = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QPageRanges.Range") -> None:
            ...

        def contains(self, pageNumber: int) -> bool:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpageranges.html#QPageRanges

        **QPageRanges::QPageRanges()**

        Constructs an empty QPageRanges object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QPageRanges") -> None:
        """
        https://doc.qt.io/qt-6/qpageranges.html#QPageRanges-1

        **QPageRanges::QPageRanges(const QPageRanges & other )**

        Constructs a QPageRanges object by copying **other**.
        """
        ...

    def lastPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qpageranges.html#lastPage

        **int QPageRanges::lastPage() const**

        Returns the index of the last page covered by the page ranges, or 0 if
        the page ranges are empty.
        """
        ...

    def firstPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qpageranges.html#firstPage

        **int QPageRanges::firstPage() const**

        Returns the index of the first page covered by the page ranges, or 0 if
        the page ranges are empty.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpageranges.html#isEmpty

        **bool QPageRanges::isEmpty() const**

        Returns `true` if the ranges are empty; otherwise returns `false`.
        """
        ...

    def contains(self, pageNumber: int) -> bool:
        """
        https://doc.qt.io/qt-6/qpageranges.html#contains

        **bool QPageRanges::contains(int pageNumber ) const**

        Returns `true` if the ranges include the page **pageNumber** ; otherwise
        returns `false`.
        """
        ...

    @staticmethod
    def fromString(ranges: str) -> "QPageRanges":
        """
        https://doc.qt.io/qt-6/qpageranges.html#fromString

        **[static] QPageRanges QPageRanges::fromString(const QString & ranges
        )**

        Constructs and returns a **QPageRanges**  object populated with the
        **ranges** from the string representation.

        **QPrinter**  printer;
            **QPageRanges**  ranges = **QPageRanges**
        ::fromString("1-3,6-7");
            printer.setPageRanges(ranges);

        In case of parsing error, returns an empty **QPageRanges**  object.

        **See also** **isEmpty** ().
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qpageranges.html#toString

        **QString QPageRanges::toString() const**

        Returns the string representation of the page ranges.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qpageranges.html#clear

        **void QPageRanges::clear()**

        Removes all page ranges.
        """
        ...

    def toRangeList(self) -> typing.List["QPageRanges.Range"]:
        """
        https://doc.qt.io/qt-6/qpageranges.html#toRangeList

        **QList<QPageRanges::Range> QPageRanges::toRangeList() const**

        Returns a list with the values of the ranges.
        """
        ...

    def addRange(self, from_: int, to: int) -> None:
        """
        https://doc.qt.io/qt-6/qpageranges.html#addRange

        **void QPageRanges::addRange(int from , int to )**

        Adds the range specified with **from** and **to** to the ranges.

        **Note:** Page numbers start with 1. Attempts to add page numbers
        smaller than 1 will be ignored with a warning.
        """
        ...

    def addPage(self, pageNumber: int) -> None:
        """
        https://doc.qt.io/qt-6/qpageranges.html#addPage

        **void QPageRanges::addPage(int pageNumber )**

        Adds the single page **pageNumber** to the ranges.

        **Note:** Page numbers start with 1. Attempts to add page numbers
        smaller than 1 will be ignored with a warning.
        """
        ...

    def swap(self, other: "QPageRanges") -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneHelpEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenehelpevent.html

    **Detailed Description**

    When a **QGraphicsView**  receives a **QEvent**  of type **QEvent::ToolTip**
    , it creates a QGraphicsSceneHelpEvent, which is forwarded to the scene. You
    can set a tooltip on a **QGraphicsItem**  with **setToolTip** (); by default
    **QGraphicsScene**  displays the tooltip of the **QGraphicsItem**  with the
    highest z-value (i.e, the top-most item) under the mouse position.

    **QGraphicsView**  does not forward events when **"What's This"**  and
    **status tip**  help is requested. If you need this, you can reimplement
    **QGraphicsView::viewportEvent** () and forward **QStatusTipEvent**  events
    and **QEvents**  of type **QEvent::WhatsThis**  to the scene.

    **See also** **QEvent** .
    """

    def screenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehelpevent.html#screenPos

        **QPoint QGraphicsSceneHelpEvent::screenPos() const**

        Returns the position of the mouse cursor in screen coordinates at the
        moment the help event was sent.

        **See also** **scenePos** ().
        """
        ...

    def scenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenehelpevent.html#scenePos

        **QPointF QGraphicsSceneHelpEvent::scenePos() const**

        Returns the position of the mouse cursor in scene coordinates at the
        moment the help event was sent.

        **See also** **screenPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QStaticText(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qstatictext.html

    **Detailed Description**

    QStaticText provides a way to cache layout data for a block of text so that
    it can be drawn more efficiently than by using **QPainter::drawText** () in
    which the layout information is recalculated with every call.

    The class primarily provides an optimization for cases where the text, its
    font and the transformations on the painter are static over several paint
    events. If the text or its layout is changed for every iteration,
    **QPainter::drawText** () is the more efficient alternative, since the
    static text's layout would have to be recalculated to take the new state
    into consideration.

    Translating the painter will not cause the layout of the text to be
    recalculated, but will cause a very small performance impact on
    drawStaticText(). Altering any other parts of the painter's transformation
    or the painter's font will cause the layout of the static text to be
    recalculated. This should be avoided as often as possible to maximize the
    performance benefit of using QStaticText.

    In addition, only affine transformations are supported by drawStaticText().
    Calling drawStaticText() on a projected painter will perform slightly worse
    than using the regular drawText() call, so this should be avoided.

    class MyWidget: public **QWidget**
        {
        public:
    MyWidget(**QWidget**  *parent = nullptr) : **QWidget** (parent),
    m_staticText("This is static text")

        protected:
            void
    paintEvent(**QPaintEvent**  *)
            {
                **QPainter**
    painter(this);
                painter.drawStaticText(0, 0, m_staticText);
    }

        private:
            **QStaticText**  m_staticText;
        };

    The QStaticText class can be used to mimic the behavior of
    **QPainter::drawText** () to a specific point with no boundaries, and also
    when **QPainter::drawText** () is called with a bounding rectangle.

    If a bounding rectangle is not required, create a QStaticText object without
    setting a preferred text width. The text will then occupy a single line.

    If you set a text width on the QStaticText object, this will bound the text.
    The text will be formatted so that no line exceeds the given width. The text
    width set for QStaticText will not automatically be used for clipping. To
    achieve clipping in addition to line breaks, use **QPainter::setClipRect**
    (). The position of the text is decided by the argument passed to
    **QPainter::drawStaticText** () and can change from call to call with a
    minimal impact on performance.

    For extra convenience, it is possible to apply formatting to the text using
    the HTML subset supported by **QTextDocument** . QStaticText will attempt to
    guess the format of the input text using **Qt::mightBeRichText** (), and
    interpret it as rich text if this function returns `true`. To force
    QStaticText to display its contents as either plain text or rich text, use
    the function **QStaticText::setTextFormat** () and pass in, respectively,
    **Qt::PlainText**  and **Qt::RichText** .

    QStaticText can only represent text, so only HTML tags which alter the
    layout or appearance of the text will be respected. Adding an image to the
    input HTML, for instance, will cause the image to be included as part of the
    layout, affecting the positions of the text glyphs, but it will not be
    displayed. The result will be an empty area the size of the image in the
    output. Similarly, using tables will cause the text to be laid out in table
    format, but the borders will not be drawn.

    If it's the first time the static text is drawn, or if the static text, or
    the painter's font has been altered since the last time it was drawn, the
    text's layout has to be recalculated. On some paint engines, changing the
    matrix of the painter will also cause the layout to be recalculated. In
    particular, this will happen for any engine except for the OpenGL2 paint
    engine. Recalculating the layout will impose an overhead on the
    **QPainter::drawStaticText** () call where it occurs. To avoid this overhead
    in the paint event, you can call **prepare** () ahead of time to ensure that
    the layout is calculated.

    **See also** **QPainter::drawText** (), **QPainter::drawStaticText** (),
    **QTextLayout** , and **QTextDocument** .
    """

    class PerformanceHint(enum.Enum):
        ModerateCaching: QStaticText = ...
        AggressiveCaching: QStaticText = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#QStaticText

        **QStaticText::QStaticText()**

        Constructs an empty QStaticText
        """
        ...

    @typing.overload
    def __init__(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#QStaticText-1

        **QStaticText::QStaticText(const QString & text )**

        Constructs a QStaticText object with the given **text**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStaticText") -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#QStaticText-2

        **QStaticText::QStaticText(const QStaticText & other )**

        Constructs a QStaticText object which is a copy of **other**.
        """
        ...

    def swap(self, other: "QStaticText") -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#swap

        **[since 5.0] void QStaticText::swap(QStaticText & other )**

        Swaps this static text instance with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def performanceHint(self) -> "QStaticText.PerformanceHint":
        """
        https://doc.qt.io/qt-6/qstatictext.html#performanceHint

        **QStaticText::PerformanceHint QStaticText::performanceHint() const**

        Returns which performance hint is set for the **QStaticText** .

        **See also** **setPerformanceHint** ().
        """
        ...

    def setPerformanceHint(
        self, performanceHint: "QStaticText.PerformanceHint"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#setPerformanceHint

        **void QStaticText::setPerformanceHint(QStaticText::PerformanceHint
        performanceHint )**

        Sets the performance hint of the **QStaticText**  according to the
        **performanceHint** provided. The **performanceHint** is used to
        customize how much caching is done internally to improve performance.

        The default is **QStaticText::ModerateCaching** .

        **Note:** This function will cause the layout of the text to require
        recalculation.

        **See also** **performanceHint** ().
        """
        ...

    def prepare(self, matrix: "QTransform" = ..., font: QFont = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#prepare

        **void QStaticText::prepare(const QTransform & matrix = QTransform(),
        const QFont & font = QFont())**

        Prepares the **QStaticText**  object for being painted with the given
        **matrix** and the given **font** to avoid overhead when the actual
        drawStaticText() call is made.

        When drawStaticText() is called, the layout of the **QStaticText**  will
        be recalculated if any part of the **QStaticText**  object has changed
        since the last time it was drawn. It will also be recalculated if the
        painter's font is not the same as when the **QStaticText**  was last
        drawn, or, on any other paint engine than the OpenGL2 engine, if the
        painter's matrix has been altered since the static text was last drawn.

        To avoid the overhead of creating the layout the first time you draw the
        **QStaticText**  after making changes, you can use the prepare()
        function and pass in the **matrix** and **font** you expect to use when
        drawing the text.

        **See also** **QPainter::setFont** () and
        **QPainter::setWorldTransform** ().
        """
        ...

    def size(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qstatictext.html#size

        **QSizeF QStaticText::size() const**

        Returns the size of the bounding rect for this **QStaticText** .

        **See also** **textWidth** ().
        """
        ...

    def textOption(self) -> "QTextOption":
        """
        https://doc.qt.io/qt-6/qstatictext.html#textOption

        **QTextOption QStaticText::textOption() const**

        Returns the current text option used to control the layout process.

        **See also** **setTextOption** ().
        """
        ...

    def setTextOption(self, textOption: "QTextOption") -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#setTextOption

        **void QStaticText::setTextOption(const QTextOption & textOption )**

        Sets the text option structure that controls the layout process to the
        given **textOption**.

        **See also** **textOption** ().
        """
        ...

    def textWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qstatictext.html#textWidth

        **qreal QStaticText::textWidth() const**

        Returns the preferred width for this **QStaticText** .

        **See also** **setTextWidth** ().
        """
        ...

    def setTextWidth(self, textWidth: float) -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#setTextWidth

        **void QStaticText::setTextWidth(qreal textWidth )**

        Sets the preferred width for this **QStaticText** . If the text is wider
        than the specified width, it will be broken into multiple lines and grow
        vertically. If the text cannot be split into multiple lines, it will be
        larger than the specified **textWidth**.

        Setting the preferred text width to a negative number will cause the
        text to be unbounded.

        Use **size** () to get the actual size of the text.

        **Note:** This function will cause the layout of the text to require
        recalculation.

        **See also** **textWidth** () and **size** ().
        """
        ...

    def textFormat(self) -> QtCore.Qt.TextFormat:
        """
        https://doc.qt.io/qt-6/qstatictext.html#textFormat

        **Qt::TextFormat QStaticText::textFormat() const**

        Returns the text format of the **QStaticText** .

        **See also** **setTextFormat** (), **setText** (), and **text** ().
        """
        ...

    def setTextFormat(self, textFormat: QtCore.Qt.TextFormat) -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#setTextFormat

        **void QStaticText::setTextFormat(Qt::TextFormat textFormat )**

        Sets the text format of the **QStaticText**  to **textFormat**. If
        **textFormat** is set to **Qt::AutoText**  (the default), the format of
        the text will try to be determined using the function
        **Qt::mightBeRichText** (). If the text format is **Qt::PlainText** ,
        then the text will be displayed as is, whereas it will be interpreted as
        HTML if the format is **Qt::RichText** . HTML tags that alter the font
        of the text, its color, or its layout are supported by **QStaticText** .

        **Note:** This function will cause the layout of the text to require
        recalculation.

        **See also** **textFormat** (), **setText** (), and **text** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qstatictext.html#text

        **QString QStaticText::text() const**

        Returns the text of the **QStaticText** .

        **See also** **setText** ().
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qstatictext.html#setText

        **void QStaticText::setText(const QString & text )**

        Sets the text of the **QStaticText**  to **text**.

        **Note:** This function will cause the layout of the text to require
        recalculation.

        **See also** **text** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QOpenGLVertexArrayObject(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopenglvertexarrayobject.html

    **Detailed Description**

    A Vertex Array Object (VAO) is an OpenGL container object that encapsulates
    the state needed to specify per-vertex attribute data to the OpenGL
    pipeline. To put it another way, a VAO remembers the states of buffer
    objects (see **QOpenGLBuffer** ) and their associated state (e.g. vertex
    attribute divisors). This allows a very easy and efficient method of
    switching between OpenGL buffer states for rendering different "objects" in
    a scene. The QOpenGLVertexArrayObject class is a thin wrapper around an
    OpenGL VAO.

    For the desktop, VAOs are supported as a core feature in OpenGL 3.0 or newer
    and by the GL_ARB_vertex_array_object for older versions. On OpenGL ES 2,
    VAOs are provided by the optional GL_OES_vertex_array_object extension. You
    can check the version of OpenGL with QOpenGLContext::surfaceFormat() and
    check for the presence of extensions with **QOpenGLContext::hasExtension**
    ().

    As with the other Qt OpenGL classes, QOpenGLVertexArrayObject has a
    **create** () function to create the underlying OpenGL object. This is to
    allow the developer to ensure that there is a valid current OpenGL context
    at the time.

    Once you have successfully created a VAO the typical usage pattern is:

    * In scene initialization function, for each visual object:
        * Bind the
    VAO
        * Set vertex data state for this visual object (vertices, normals,
    texture coordinates etc.)
        * Unbind (**release** ()) the VAO
      * In
    render function, for each visual object:
        * Bind the VAO (and shader
    program if needed)
        * Call a glDraw*() function
        * Unbind (**release**
    ()) the VAO

    The act of binding the VAO in the render function has the effect of
    restoring all of the vertex data state setup in the initialization phase. In
    this way we can set a great deal of state when setting up a VAO and
    efficiently switch between state sets of objects to be rendered. Using VAOs
    also allows the OpenGL driver to amortise the validation checks of the
    vertex data.

    **Note:** Vertex Array Objects, like all other OpenGL container objects, are
    specific to the context for which they were created and cannot be shared
    amongst a context group.

    **See also** **QOpenGLVertexArrayObject::Binder**  and **QOpenGLBuffer** .
    """

    class Binder(PyQt6.sip.simplewrapper):
        def __init__(self, v: "QOpenGLVertexArrayObject") -> None:
            ...

        def __exit__(
            self, type: typing.Any, value: typing.Any, traceback: typing.Any
        ) -> None:
            ...

        def __enter__(self) -> typing.Any:
            ...

        def rebind(self) -> None:
            ...

        def release(self) -> None:
            ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopenglvertexarrayobject.html#QOpenGLVertexArrayO
        bject

        **QOpenGLVertexArrayObject::QOpenGLVertexArrayObject(QObject * parent =
        nullptr)**

        Creates a QOpenGLVertexArrayObject with the given **parent**. You must
        call **create** () with a valid OpenGL context before using.
        """
        ...

    def release(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglvertexarrayobject.html#release

        **void QOpenGLVertexArrayObject::release()**

        Unbinds this vertex array object by binding the default vertex array
        object (id = 0).
        """
        ...

    def bind(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglvertexarrayobject.html#bind

        **void QOpenGLVertexArrayObject::bind()**

        Binds this vertex array object to the OpenGL binding point. From this
        point on and until **release** () is called or another vertex array
        object is bound, any modifications made to vertex data state are stored
        inside this vertex array object.

        If another vertex array object is then bound you can later restore the
        set of state associated with this object by calling bind() on this
        object once again. This allows efficient changes between vertex data
        states in rendering functions.
        """
        ...

    def objectId(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglvertexarrayobject.html#objectId

        **GLuint QOpenGLVertexArrayObject::objectId() const**

        Returns the id of the underlying OpenGL vertex array object.
        """
        ...

    def isCreated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglvertexarrayobject.html#isCreated

        **bool QOpenGLVertexArrayObject::isCreated() const**

        Returns `true` is the underlying OpenGL vertex array object has been
        created. If this returns `true` and the associated OpenGL context is
        current, then you are able to **bind** () this object.
        """
        ...

    def destroy(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglvertexarrayobject.html#destroy

        **void QOpenGLVertexArrayObject::destroy()**

        Destroys the underlying OpenGL vertex array object. There must be a
        valid OpenGL context that supports vertex array objects current for this
        function to succeed.
        """
        ...

    def create(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglvertexarrayobject.html#create

        **bool QOpenGLVertexArrayObject::create()**

        Creates the underlying OpenGL vertex array object. There must be a valid
        OpenGL context that supports vertex array objects current for this
        function to succeed.

        Returns `true` if the OpenGL vertex array object was successfully
        created.

        When the return value is `false`, vertex array object support is not
        available. This is not an error: on systems with OpenGL 2.x or OpenGL ES
        2.0 vertex array objects may not be supported. The application is free
        to continue execution in this case, but it then has to be prepared to
        operate in a VAO-less manner too. This means that instead of merely
        calling **bind** (), the value of **isCreated** () must be checked and
        the vertex arrays has to be initialized in the traditional way when
        there is no vertex array object present.

        **See also** **isCreated** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtBluetooth import *


class QBluetoothHostInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbluetoothhostinfo.html

    **Detailed Description**

    This class holds the name and address of a local Bluetooth device.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothhostinfo.html#QBluetoothHostInfo

        **QBluetoothHostInfo::QBluetoothHostInfo()**

        Constructs a null QBluetoothHostInfo object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QBluetoothHostInfo") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothhostinfo.html#QBluetoothHostInfo-1

        **QBluetoothHostInfo::QBluetoothHostInfo(const QBluetoothHostInfo &
        other )**

        Constructs a new QBluetoothHostInfo which is a copy of **other**.
        """
        ...

    def setName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothhostinfo.html#setName

        **void QBluetoothHostInfo::setName(const QString & name )**

        Sets the **name** of the host info object.

        **See also** **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothhostinfo.html#name

        **QString QBluetoothHostInfo::name() const**

        Returns the user visible name of the host info object.

        **See also** **setName** ().
        """
        ...

    def setAddress(self, address: QBluetoothAddress) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothhostinfo.html#setAddress

        **void QBluetoothHostInfo::setAddress(const QBluetoothAddress & address
        )**

        Sets the Bluetooth **address** for this Bluetooth host info object.

        **See also** **address** ().
        """
        ...

    def address(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qbluetoothhostinfo.html#address

        **QBluetoothAddress QBluetoothHostInfo::address() const**

        Returns the Bluetooth address as a **QBluetoothAddress** .

        **See also** **setAddress** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QComboBox(QWidget):
    """
    https://doc.qt.io/qt-6/qcombobox.html

    **Detailed Description**

    ![](images/windows-combobox.png)

    A QComboBox provides a means of presenting a list of options to the user in
    a way that takes up the minimum amount of screen space.

    A combobox is a selection widget that displays the current item, and can pop
    up a list of selectable items. A combobox may be editable, allowing the user
    to modify each item in the list.

    Comboboxes can contain pixmaps as well as strings; the **insertItem** () and
    **setItemText** () functions are suitably overloaded. For editable
    comboboxes, the function **clearEditText** () is provided, to clear the
    displayed string without changing the combobox's contents.

    There are three signals emitted if the current item of a combobox changes,
    **currentIndexChanged** (), **currentTextChanged** () and **activated** ().
    **currentIndexChanged** () and **currentTextChanged** () are always emitted
    regardless if the change was done programmatically or by user interaction,
    while **activated** () is only emitted when the change is caused by user
    interaction. The **highlighted** () signal is emitted when the user
    highlights an item in the combobox popup list. All three signals exist in
    two versions, one with a **QString**  argument and one with an `int`
    argument. If the user selects or highlights a pixmap, only the `int` signals
    are emitted. Whenever the text of an editable combobox is changed the
    **editTextChanged** () signal is emitted.

    When the user enters a new string in an editable combobox, the widget may or
    may not insert it, and it can insert it in several locations. The default
    policy is **InsertAtBottom**  but you can change this using
    **setInsertPolicy** ().

    It is possible to constrain the input to an editable combobox using
    **QValidator** ; see **setValidator** (). By default, any input is accepted.

    A combobox can be populated using the insert functions, **insertItem** ()
    and **insertItems** () for example. Items can be changed with
    **setItemText** (). An item can be removed with **removeItem** () and all
    items can be removed with **clear** (). The text of the current item is
    returned by **currentText** (), and the text of a numbered item is returned
    with text(). The current item can be set with **setCurrentIndex** (). The
    number of items in the combobox is returned by **count** (); the maximum
    number of items can be set with **setMaxCount** (). You can allow editing
    using **setEditable** (). For editable comboboxes you can set auto-
    completion using **setCompleter** () and whether or not the user can add
    duplicates is set with **setDuplicatesEnabled** ().

    QComboBox uses the **model/view framework**  for its popup list and to store
    its items. By default a **QStandardItemModel**  stores the items and a
    **QListView**  subclass displays the popuplist. You can access the model and
    view directly (with **model** () and **view** ()), but QComboBox also
    provides functions to set and get item data (e.g., **setItemData** () and
    **itemText** ()). You can also set a new model and view (with **setModel**
    () and **setView** ()). For the text and icon in the combobox label, the
    data in the model that has the **Qt::DisplayRole**  and
    **Qt::DecorationRole**  is used. Note that you cannot alter the
    **SelectionMode**  of the **view** (), e.g., by using **setSelectionMode**
    ().

    **See also** **QLineEdit** , **QSpinBox** , **QRadioButton** ,
    **QButtonGroup** , and **GUI Design Handbook: Combo Box, Drop-Down List
    Box** .
    """

    class SizeAdjustPolicy(enum.Enum):
        AdjustToContents: QComboBox = ...
        AdjustToContentsOnFirstShow: QComboBox = ...
        AdjustToMinimumContentsLengthWithIcon: QComboBox = ...

    class InsertPolicy(enum.Enum):
        NoInsert: QComboBox = ...
        InsertAtTop: QComboBox = ...
        InsertAtCurrent: QComboBox = ...
        InsertAtBottom: QComboBox = ...
        InsertAfterCurrent: QComboBox = ...
        InsertBeforeCurrent: QComboBox = ...
        InsertAlphabetically: QComboBox = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#QComboBox

        **QComboBox::QComboBox(QWidget * parent = nullptr)**

        Constructs a combobox with the given **parent** , using the default
        model **QStandardItemModel** .
        """
        ...

    def placeholderText(self) -> str:
        """
        https://doc.qt.io/qt-6/qcombobox.html#placeholderText-prop

        **[since 5.15] placeholderText : QString**

        Sets a **placeholderText** text shown when no valid index is set

        The **placeholderText** will be shown when an invalid index is set. The
        text is not accessible in the dropdown list. When this function is
        called before items are added the placeholder text will be shown,
        otherwise you have to call **setCurrentIndex** (-1) programmatically if
        you want to show the placeholder text. Set an empty placeholder text to
        reset the setting.

        When the **QComboBox**  is editable, use
        **QLineEdit::setPlaceholderText** () instead.

        This property was introduced in Qt 5.15.

        **Access functions:**

        QString **placeholderText** () const
        void **setPlaceholderText**
        (const QString & **placeholderText** )
        """
        ...

    def setPlaceholderText(self, placeholderText: str) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#placeholderText-prop

        **[since 5.15] placeholderText : QString**

        Sets a **placeholderText** text shown when no valid index is set

        The **placeholderText** will be shown when an invalid index is set. The
        text is not accessible in the dropdown list. When this function is
        called before items are added the placeholder text will be shown,
        otherwise you have to call **setCurrentIndex** (-1) programmatically if
        you want to show the placeholder text. Set an empty placeholder text to
        reset the setting.

        When the **QComboBox**  is editable, use
        **QLineEdit::setPlaceholderText** () instead.

        This property was introduced in Qt 5.15.

        **Access functions:**

        QString **placeholderText** () const
        void **setPlaceholderText**
        (const QString & **placeholderText** )
        """
        ...

    def currentData(self, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qcombobox.html#currentData-prop

        **[read-only, since 5.2] currentData : const QVariant**

        This property holds the data for the current item

        By default, for an empty combo box or a combo box in which no current
        item is set, this property contains an invalid **QVariant** .

        This property was introduced in Qt 5.2.

        **Access functions:**

        QVariant **currentData** (int **role** = Qt::UserRole) const
        """
        ...

    @typing.overload
    def inputMethodQuery(self, a0: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qcombobox.html#inputMethodQuery

        **[override virtual] QVariant
        QComboBox::inputMethodQuery(Qt::InputMethodQuery query ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    @typing.overload
    def inputMethodQuery(
        self, query: QtCore.Qt.InputMethodQuery, argument: typing.Any
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qcombobox.html#inputMethodQuery

        **[override virtual] QVariant
        QComboBox::inputMethodQuery(Qt::InputMethodQuery query ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    def inputMethodEvent(self, a0: QtGui.QInputMethodEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#inputMethodEvent

        **[override virtual protected] void
        QComboBox::inputMethodEvent(QInputMethodEvent * e )**

        Reimplements: **QWidget::inputMethodEvent** (QInputMethodEvent *event).
        """
        ...

    def contextMenuEvent(self, e: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#contextMenuEvent

        **[override virtual protected] void
        QComboBox::contextMenuEvent(QContextMenuEvent * e )**

        Reimplements: **QWidget::contextMenuEvent** (QContextMenuEvent *event).
        """
        ...

    def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#wheelEvent

        **[override virtual protected] void QComboBox::wheelEvent(QWheelEvent *
        e )**

        Reimplements: **QWidget::wheelEvent** (QWheelEvent *event).
        """
        ...

    def keyReleaseEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#keyReleaseEvent

        **[override virtual protected] void QComboBox::keyReleaseEvent(QKeyEvent
        * e )**

        Reimplements: **QWidget::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#keyPressEvent

        **[override virtual protected] void QComboBox::keyPressEvent(QKeyEvent *
        e )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#mouseReleaseEvent

        **[override virtual protected] void
        QComboBox::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#mousePressEvent

        **[override virtual protected] void
        QComboBox::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def hideEvent(self, e: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#hideEvent

        **[override virtual protected] void QComboBox::hideEvent(QHideEvent * e
        )**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def showEvent(self, e: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#showEvent

        **[override virtual protected] void QComboBox::showEvent(QShowEvent * e
        )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#paintEvent

        **[override virtual protected] void QComboBox::paintEvent(QPaintEvent *
        e )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def resizeEvent(self, e: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#resizeEvent

        **[override virtual protected] void QComboBox::resizeEvent(QResizeEvent
        * e )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#changeEvent

        **[override virtual protected] void QComboBox::changeEvent(QEvent * e
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def focusOutEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#focusOutEvent

        **[override virtual protected] void QComboBox::focusOutEvent(QFocusEvent
        * e )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#focusInEvent

        **[override virtual protected] void QComboBox::focusInEvent(QFocusEvent
        * e )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionComboBox") -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#initStyleOption

        **[virtual protected] void
        QComboBox::initStyleOption(QStyleOptionComboBox * option ) const**

        Initialize **option** with the values from this **QComboBox** . This
        method is useful for subclasses when they need a
        **QStyleOptionComboBox** , but don't want to fill in all the information
        themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def setCurrentText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#currentText-prop

        **currentText : QString**

        This property holds the current text

        If the combo box is editable, the current text is the value displayed by
        the line edit. Otherwise, it is the value of the current item or an
        empty string if the combo box is empty or no current item is set.

        The setter setCurrentText() simply calls **setEditText** () if the combo
        box is editable. Otherwise, if there is a matching text in the list,
        **currentIndex**  is set to the corresponding index.

        **Access functions:**

        QString **currentText** () const
        void **setCurrentText** (const
        QString & **text** )

        **Notifier signal:**

        void ****currentTextChanged** ** (const QString & **text** )

        **See also** **editable**  and **setEditText** ().
        """
        ...

    def setEditText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setEditText

        **[slot] void QComboBox::setEditText(const QString & text )**

        Sets the **text** in the combobox's text edit.
        """
        ...

    def clearEditText(self) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#clearEditText

        **[slot] void QComboBox::clearEditText()**

        Clears the contents of the line edit used for editing in the combobox.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#clear

        **[slot] void QComboBox::clear()**

        Clears the combobox, removing all items.

        Note: If you have set an external model on the combobox this model will
        still be cleared when calling this function.
        """
        ...

    def insertSeparator(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#insertSeparator

        **void QComboBox::insertSeparator(int index )**

        Inserts a separator item into the combobox at the given **index**.

        If the index is equal to or higher than the total number of items, the
        new item is appended to the list of existing items. If the index is zero
        or negative, the new item is prepended to the list of existing items.

        **See also** **insertItem** ().
        """
        ...

    def completer(self) -> "QCompleter":
        """
        https://doc.qt.io/qt-6/qcombobox.html#completer

        **QCompleter *QComboBox::completer() const**

        Returns the completer that is used to auto complete text input for the
        combobox.

        **See also** **setCompleter** () and **editable** .
        """
        ...

    def setCompleter(self, c: "QCompleter") -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setCompleter

        **void QComboBox::setCompleter(QCompleter * completer )**

        Sets the **completer** to use instead of the current completer. If
        **completer** is `nullptr`, auto completion is disabled.

        By default, for an editable combo box, a **QCompleter**  that performs
        case insensitive inline completion is automatically created.

        **Note:** The completer is removed when the **editable**  property
        becomes `false`, or when the line edit is replaced by a call to
        **setLineEdit** (). Setting a completer on a **QComboBox**  that is not
        editable will be ignored.

        **See also** **completer** ().
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qcombobox.html#event

        **[override virtual] bool QComboBox::event(QEvent * event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def hidePopup(self) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#hidePopup

        **[virtual] void QComboBox::hidePopup()**

        Hides the list of items in the combobox if it is currently visible and
        resets the internal state, so that if the custom pop-up was shown inside
        the reimplemented **showPopup** (), then you also need to reimplement
        the hidePopup() function to hide your custom pop-up and call the base
        class implementation to reset the internal state whenever your custom
        pop-up widget is hidden.

        **See also** **showPopup** ().
        """
        ...

    def showPopup(self) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#showPopup

        **[virtual] void QComboBox::showPopup()**

        Displays the list of items in the combobox. If the list is empty then no
        items will be shown.

        If you reimplement this function to show a custom pop-up, make sure you
        call **hidePopup** () to reset the internal state.

        **See also** **hidePopup** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcombobox.html#minimumSizeHint

        **[override virtual] QSize QComboBox::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcombobox.html#sizeHint

        **[override virtual] QSize QComboBox::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .

        This implementation caches the size hint to avoid resizing when the
        contents change dynamically. To invalidate the cached value change the
        **sizeAdjustPolicy** .
        """
        ...

    def setView(self, itemView: QAbstractItemView) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setView

        **void QComboBox::setView(QAbstractItemView * itemView )**

        Sets the view to be used in the combobox popup to the given
        **itemView**. The combobox takes ownership of the view.

        Note: If you want to use the convenience views (like **QListWidget** ,
        **QTableWidget**  or **QTreeWidget** ), make sure to call **setModel**
        () on the combobox with the convenience widgets model before calling
        this function.

        **See also** **view** ().
        """
        ...

    def view(self) -> QAbstractItemView:
        """
        https://doc.qt.io/qt-6/qcombobox.html#view

        **QAbstractItemView *QComboBox::view() const**

        Returns the list view used for the combobox popup.

        **See also** **setView** ().
        """
        ...

    def setItemData(self, index: int, value: typing.Any, role: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setItemData

        **void QComboBox::setItemData(int index , const QVariant & value , int
        role = Qt::UserRole)**

        Sets the data **role** for the item on the given **index** in the
        combobox to the specified **value**.

        **See also** **itemData** ().
        """
        ...

    def setItemIcon(self, index: int, icon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setItemIcon

        **void QComboBox::setItemIcon(int index , const QIcon & icon )**

        Sets the **icon** for the item on the given **index** in the combobox.

        **See also** **itemIcon** ().
        """
        ...

    def setItemText(self, index: int, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setItemText

        **void QComboBox::setItemText(int index , const QString & text )**

        Sets the **text** for the item on the given **index** in the combobox.

        **See also** **itemText** ().
        """
        ...

    def removeItem(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#removeItem

        **void QComboBox::removeItem(int index )**

        Removes the item at the given **index** from the combobox. This will
        update the current index if the index is removed.

        This function does nothing if **index** is out of range.
        """
        ...

    def insertItems(self, index: int, texts: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#insertItems

        **void QComboBox::insertItems(int index , const QStringList & list )**

        Inserts the strings from the **list** into the combobox as separate
        items, starting at the **index** specified.

        If the index is equal to or higher than the total number of items, the
        new items are appended to the list of existing items. If the index is
        zero or negative, the new items are prepended to the list of existing
        items.

        **See also** **insertItem** ().
        """
        ...

    @typing.overload
    def insertItem(self, index: int, text: str, userData: typing.Any = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#insertItem

        **void QComboBox::insertItem(int index , const QString & text , const
        QVariant & userData = QVariant())**

        Inserts the **text** and **userData** (stored in the **Qt::UserRole** )
        into the combobox at the given **index**.

        If the index is equal to or higher than the total number of items, the
        new item is appended to the list of existing items. If the index is zero
        or negative, the new item is prepended to the list of existing items.

        **See also** **insertItems** ().
        """
        ...

    @typing.overload
    def insertItem(
        self, index: int, icon: QtGui.QIcon, text: str, userData: typing.Any = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#insertItem-1

        **void QComboBox::insertItem(int index , const QIcon & icon , const
        QString & text , const QVariant & userData = QVariant())**

        Inserts the **icon** , **text** and **userData** (stored in the
        **Qt::UserRole** ) into the combobox at the given **index**.

        If the index is equal to or higher than the total number of items, the
        new item is appended to the list of existing items. If the index is zero
        or negative, the new item is prepended to the list of existing items.

        **See also** **insertItems** ().
        """
        ...

    @typing.overload
    def addItem(self, text: str, userData: typing.Any = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#addItem

        **void QComboBox::addItem(const QString & text , const QVariant &
        userData = QVariant())**

        Adds an item to the combobox with the given **text** , and containing
        the specified **userData** (stored in the **Qt::UserRole** ). The item
        is appended to the list of existing items.
        """
        ...

    @typing.overload
    def addItem(self, icon: QtGui.QIcon, text: str, userData: typing.Any = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#addItem-1

        **void QComboBox::addItem(const QIcon & icon , const QString & text ,
        const QVariant & userData = QVariant())**

        Adds an item to the combobox with the given **icon** and **text** , and
        containing the specified **userData** (stored in the **Qt::UserRole** ).
        The item is appended to the list of existing items.
        """
        ...

    def addItems(self, texts: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#addItems

        **void QComboBox::addItems(const QStringList & texts )**

        Adds each of the strings in the given **texts** to the combobox. Each
        item is appended to the list of existing items in turn.
        """
        ...

    def itemData(self, index: int, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qcombobox.html#itemData

        **QVariant QComboBox::itemData(int index , int role = Qt::UserRole)
        const**

        Returns the data for the given **role** in the given **index** in the
        combobox, or an invalid **QVariant**  if there is no data for this role.

        **See also** **setItemData** ().
        """
        ...

    def itemIcon(self, index: int) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qcombobox.html#itemIcon

        **QIcon QComboBox::itemIcon(int index ) const**

        Returns the icon for the given **index** in the combobox.

        **See also** **setItemIcon** ().
        """
        ...

    def itemText(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qcombobox.html#itemText

        **QString QComboBox::itemText(int index ) const**

        Returns the text for the given **index** in the combobox.

        **See also** **setItemText** ().
        """
        ...

    def currentText(self) -> str:
        """
        https://doc.qt.io/qt-6/qcombobox.html#currentText-prop

        **currentText : QString**

        This property holds the current text

        If the combo box is editable, the current text is the value displayed by
        the line edit. Otherwise, it is the value of the current item or an
        empty string if the combo box is empty or no current item is set.

        The setter setCurrentText() simply calls **setEditText** () if the combo
        box is editable. Otherwise, if there is a matching text in the list,
        **currentIndex**  is set to the corresponding index.

        **Access functions:**

        QString **currentText** () const
        void **setCurrentText** (const
        QString & **text** )

        **Notifier signal:**

        void ****currentTextChanged** ** (const QString & **text** )

        **See also** **editable**  and **setEditText** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index of the current item in the combobox.

        The current index can change when inserting or removing items.

        By default, for an empty combo box or a combo box in which no current
        item is set, this property has a value of -1.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentIndexChanged** ** (int **index** )
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index of the current item in the combobox.

        The current index can change when inserting or removing items.

        By default, for an empty combo box or a combo box in which no current
        item is set, this property has a value of -1.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentIndexChanged** ** (int **index** )
        """
        ...

    def setModelColumn(self, visibleColumn: int) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#modelColumn-prop

        **modelColumn : int**

        This property holds the column in the model that is visible.

        If set prior to populating the combo box, the pop-up view will not be
        affected and will show the first column (using this property's default
        value).

        By default, this property has a value of 0.

        **Note:** In an editable combobox, the visible column will also become
        the **completion column** .

        **Access functions:**

        int **modelColumn** () const
        void **setModelColumn** (int
        **visibleColumn** )
        """
        ...

    def modelColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#modelColumn-prop

        **modelColumn : int**

        This property holds the column in the model that is visible.

        If set prior to populating the combo box, the pop-up view will not be
        affected and will show the first column (using this property's default
        value).

        By default, this property has a value of 0.

        **Note:** In an editable combobox, the visible column will also become
        the **completion column** .

        **Access functions:**

        int **modelColumn** () const
        void **setModelColumn** (int
        **visibleColumn** )
        """
        ...

    def setRootModelIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setRootModelIndex

        **void QComboBox::setRootModelIndex(const QModelIndex & index )**

        Sets the root model item **index** for the items in the combobox.

        **See also** **rootModelIndex** ().
        """
        ...

    def rootModelIndex(self) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qcombobox.html#rootModelIndex

        **QModelIndex QComboBox::rootModelIndex() const**

        Returns the root model item index for the items in the combobox.

        **See also** **setRootModelIndex** ().
        """
        ...

    def setModel(self, model: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setModel

        **[virtual] void QComboBox::setModel(QAbstractItemModel * model )**

        Sets the model to be **model**. **model** must not be `nullptr`. If you
        want to clear the contents of a model, call **clear** ().

        **Note:** If the combobox is editable, then the **model** will also be
        set on the completer of the line edit.

        **See also** **model** (), **clear** (), and **setCompleter** ().
        """
        ...

    def model(self) -> QtCore.QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qcombobox.html#model

        **QAbstractItemModel *QComboBox::model() const**

        Returns the model used by the combobox.

        **See also** **setModel** ().
        """
        ...

    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setItemDelegate

        **void QComboBox::setItemDelegate(QAbstractItemDelegate * delegate )**

        Sets the item **delegate** for the popup list view. The combobox takes
        ownership of the delegate.

        Any existing delegate will be removed, but not deleted. **QComboBox**
        does not take ownership of **delegate**.

        **Warning:** You should not share the same instance of a delegate
        between comboboxes, widget mappers or views. Doing so can cause
        incorrect or unintuitive editing behavior since each view connected to a
        given delegate may receive the **closeEditor** () signal, and attempt to
        access, modify or close an editor that has already been closed.

        **See also** **itemDelegate** ().
        """
        ...

    def itemDelegate(self) -> QAbstractItemDelegate:
        """
        https://doc.qt.io/qt-6/qcombobox.html#itemDelegate

        **QAbstractItemDelegate *QComboBox::itemDelegate() const**

        Returns the item delegate used by the popup list view.

        **See also** **setItemDelegate** ().
        """
        ...

    def validator(self) -> QtGui.QValidator:
        """
        https://doc.qt.io/qt-6/qcombobox.html#validator

        **const QValidator *QComboBox::validator() const**

        Returns the validator that is used to constrain text input for the
        combobox.

        **See also** **setValidator** () and **editable** .
        """
        ...

    def setValidator(self, v: QtGui.QValidator) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setValidator

        **void QComboBox::setValidator(const QValidator * validator )**

        Sets the **validator** to use instead of the current validator.

        **Note:** The validator is removed when the **editable**  property
        becomes `false`.

        **See also** **validator** ().
        """
        ...

    def lineEdit(self) -> "QLineEdit":
        """
        https://doc.qt.io/qt-6/qcombobox.html#lineEdit

        **QLineEdit *QComboBox::lineEdit() const**

        Returns the line edit used to edit items in the combobox, or `nullptr`
        if there is no line edit.

        Only editable combo boxes have a line edit.

        **See also** **setLineEdit** ().
        """
        ...

    def setLineEdit(self, edit: "QLineEdit") -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#setLineEdit

        **void QComboBox::setLineEdit(QLineEdit * edit )**

        Sets the line **edit** to use instead of the current line edit widget.

        The combo box takes ownership of the line edit.

        **Note:** Since the combobox's line edit owns the **QCompleter** , any
        previous call to **setCompleter** () will no longer have any effect.

        **See also** **lineEdit** ().
        """
        ...

    def setEditable(self, editable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#editable-prop

        **editable : bool**

        This property holds whether the combo box can be edited by the user

        By default, this property is `false`. The effect of editing depends on
        the insert policy.

        **Note:** When disabling the **editable** state, the validator and
        completer are removed.

        **Access functions:**

        bool **isEditable** () const
        void **setEditable** (bool **editable** )

        **See also** **InsertPolicy** .
        """
        ...

    def isEditable(self) -> bool:
        ...

    def setIconSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size of the icons shown in the combobox.

        Unless explicitly set this returns the default value of the current
        style. This size is the maximum size that icons can have; icons of
        smaller size are not scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )
        """
        ...

    def iconSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcombobox.html#iconSize-prop

        **iconSize : QSize**

        This property holds the size of the icons shown in the combobox.

        Unless explicitly set this returns the default value of the current
        style. This size is the maximum size that icons can have; icons of
        smaller size are not scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )
        """
        ...

    def setMinimumContentsLength(self, characters: int) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#minimumContentsLength-prop

        **minimumContentsLength : int**

        This property holds the minimum number of characters that should fit
        into the combobox.

        The default value is 0.

        If this property is set to a positive value, the **minimumSizeHint** ()
        and **sizeHint** () take it into account.

        **Access functions:**

        int **minimumContentsLength** () const
        void
        **setMinimumContentsLength** (int **characters** )

        **See also** **sizeAdjustPolicy** .
        """
        ...

    def minimumContentsLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#minimumContentsLength-prop

        **minimumContentsLength : int**

        This property holds the minimum number of characters that should fit
        into the combobox.

        The default value is 0.

        If this property is set to a positive value, the **minimumSizeHint** ()
        and **sizeHint** () take it into account.

        **Access functions:**

        int **minimumContentsLength** () const
        void
        **setMinimumContentsLength** (int **characters** )

        **See also** **sizeAdjustPolicy** .
        """
        ...

    def setSizeAdjustPolicy(self, policy: "QComboBox.SizeAdjustPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#sizeAdjustPolicy-prop

        **sizeAdjustPolicy : SizeAdjustPolicy**

        This property holds the policy describing how the size of the combobox
        changes when the content changes

        The default value is **AdjustToContentsOnFirstShow** .

        **Access functions:**

        QComboBox::SizeAdjustPolicy **sizeAdjustPolicy** () const
        void
        **setSizeAdjustPolicy** (QComboBox::SizeAdjustPolicy **policy** )

        **See also** **SizeAdjustPolicy** .

        **Member Function Documentation**
        """
        ...

    def sizeAdjustPolicy(self) -> "QComboBox.SizeAdjustPolicy":
        """
        https://doc.qt.io/qt-6/qcombobox.html#sizeAdjustPolicy-prop

        **sizeAdjustPolicy : SizeAdjustPolicy**

        This property holds the policy describing how the size of the combobox
        changes when the content changes

        The default value is **AdjustToContentsOnFirstShow** .

        **Access functions:**

        QComboBox::SizeAdjustPolicy **sizeAdjustPolicy** () const
        void
        **setSizeAdjustPolicy** (QComboBox::SizeAdjustPolicy **policy** )

        **See also** **SizeAdjustPolicy** .

        **Member Function Documentation**
        """
        ...

    def setInsertPolicy(self, policy: "QComboBox.InsertPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#insertPolicy-prop

        **insertPolicy : InsertPolicy**

        This property holds the policy used to determine where user-inserted
        items should appear in the combobox

        The default value is **InsertAtBottom** , indicating that new items will
        appear at the bottom of the list of items.

        **Access functions:**

        QComboBox::InsertPolicy **insertPolicy** () const
        void
        **setInsertPolicy** (QComboBox::InsertPolicy **policy** )

        **See also** **InsertPolicy** .
        """
        ...

    def insertPolicy(self) -> "QComboBox.InsertPolicy":
        """
        https://doc.qt.io/qt-6/qcombobox.html#insertPolicy-prop

        **insertPolicy : InsertPolicy**

        This property holds the policy used to determine where user-inserted
        items should appear in the combobox

        The default value is **InsertAtBottom** , indicating that new items will
        appear at the bottom of the list of items.

        **Access functions:**

        QComboBox::InsertPolicy **insertPolicy** () const
        void
        **setInsertPolicy** (QComboBox::InsertPolicy **policy** )

        **See also** **InsertPolicy** .
        """
        ...

    def findData(
        self, data: typing.Any, role: int = ..., flags: QtCore.Qt.MatchFlag = ...
    ) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#findData

        **int QComboBox::findData(const QVariant & data , int role =
        Qt::UserRole, Qt::MatchFlags flags =
        static_cast<Qt::MatchFlags>(Qt::MatchExactly|Qt::MatchCaseSensitive))
        const**

        Returns the index of the item containing the given **data** for the
        given **role** ; otherwise returns -1.

        The **flags** specify how the items in the combobox are searched.
        """
        ...

    def findText(self, text: str, flags: QtCore.Qt.MatchFlag = ...) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#findText

        **int QComboBox::findText(const QString & text , Qt::MatchFlags flags =
        Qt::MatchExactly|Qt::MatchCaseSensitive) const**

        Returns the index of the item containing the given **text** ; otherwise
        returns -1.

        The **flags** specify how the items in the combobox are searched.
        """
        ...

    def hasFrame(self) -> bool:
        ...

    def setFrame(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#frame-prop

        **frame : bool**

        This property holds whether the combo box draws itself with a frame

        If enabled (the default) the combo box draws itself inside a frame,
        otherwise the combo box draws itself without any frame.

        **Access functions:**

        bool **hasFrame** () const
        void **setFrame** (bool)
        """
        ...

    def setDuplicatesEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#duplicatesEnabled-prop

        **duplicatesEnabled : bool**

        This property holds whether the user can enter duplicate items into the
        combobox

        Note that it is always possible to programmatically insert duplicate
        items into the combobox.

        By default, this property is `false` (duplicates are not allowed).

        **Access functions:**

        bool **duplicatesEnabled** () const
        void **setDuplicatesEnabled**
        (bool **enable** )
        """
        ...

    def duplicatesEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcombobox.html#duplicatesEnabled-prop

        **duplicatesEnabled : bool**

        This property holds whether the user can enter duplicate items into the
        combobox

        Note that it is always possible to programmatically insert duplicate
        items into the combobox.

        By default, this property is `false` (duplicates are not allowed).

        **Access functions:**

        bool **duplicatesEnabled** () const
        void **setDuplicatesEnabled**
        (bool **enable** )
        """
        ...

    def maxCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#maxCount-prop

        **maxCount : int**

        This property holds the maximum number of items allowed in the combobox

        **Note:** If you set the maximum number to be less then the current
        amount of items in the combobox, the extra items will be truncated. This
        also applies if you have set an external model on the combobox.

        By default, this property's value is derived from the highest signed
        integer available (typically 2147483647).

        **Access functions:**

        int **maxCount** () const
        void **setMaxCount** (int **max** )
        """
        ...

    def setMaxCount(self, max: int) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#maxCount-prop

        **maxCount : int**

        This property holds the maximum number of items allowed in the combobox

        **Note:** If you set the maximum number to be less then the current
        amount of items in the combobox, the extra items will be truncated. This
        also applies if you have set an external model on the combobox.

        By default, this property's value is derived from the highest signed
        integer available (typically 2147483647).

        **Access functions:**

        int **maxCount** () const
        void **setMaxCount** (int **max** )
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#count-prop

        **[read-only] count : const int**

        This property holds the number of items in the combobox

        By default, for an empty combo box, this property has a value of 0.

        **Access functions:**

        int **count** () const
        """
        ...

    def setMaxVisibleItems(self, maxItems: int) -> None:
        """
        https://doc.qt.io/qt-6/qcombobox.html#maxVisibleItems-prop

        **maxVisibleItems : int**

        This property holds the maximum allowed size on screen of the combo box,
        measured in items

        By default, this property has a value of 10.

        **Note:** This property is ignored for non-editable comboboxes in styles
        that returns true for **QStyle::SH_ComboBox_Popup**  such as the Mac
        style or the Gtk+ Style.

        **Access functions:**

        int **maxVisibleItems** () const
        void **setMaxVisibleItems** (int
        **maxItems** )
        """
        ...

    def maxVisibleItems(self) -> int:
        """
        https://doc.qt.io/qt-6/qcombobox.html#maxVisibleItems-prop

        **maxVisibleItems : int**

        This property holds the maximum allowed size on screen of the combo box,
        measured in items

        By default, this property has a value of 10.

        **Note:** This property is ignored for non-editable comboboxes in styles
        that returns true for **QStyle::SH_ComboBox_Popup**  such as the Mac
        style or the Gtk+ Style.

        **Access functions:**

        int **maxVisibleItems** () const
        void **setMaxVisibleItems** (int
        **maxItems** )
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcombobox.html#activated

        **[signal] void QComboBox::activated(int index )**

        This signal is sent when the user chooses an item in the combobox. The
        item's **index** is passed. Note that this signal is sent even when the
        choice is not changed. If you need to know when the choice actually
        changes, use signal **currentIndexChanged** () or **currentTextChanged**
        ().
        """
        ...

    @property
    def currentIndexChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcombobox.html#currentIndexChanged

        **[signal] void QComboBox::currentIndexChanged(int index )**

        This signal is sent whenever the **currentIndex**  in the combobox
        changes either through user interaction or programmatically. The item's
        **index** is passed or -1 if the combobox becomes empty or the
        **currentIndex**  was reset.

        **Note:** Notifier signal for property **currentIndex** .
        """
        ...

    @property
    def currentTextChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcombobox.html#currentTextChanged

        **[signal, since 5.0] void QComboBox::currentTextChanged(const QString &
        text )**

        This signal is sent whenever **currentText**  changes. The new value is
        passed as **text**.

        **Note:** Notifier signal for property **currentText** .

        This function was introduced in Qt 5.0.
        """
        ...

    @property
    def editTextChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcombobox.html#editTextChanged

        **[signal] void QComboBox::editTextChanged(const QString & text )**

        This signal is emitted when the text in the combobox's line edit widget
        is changed. The new text is specified by **text**.
        """
        ...

    @property
    def highlighted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcombobox.html#highlighted

        **[signal] void QComboBox::highlighted(int index )**

        This signal is sent when an item in the combobox popup list is
        highlighted by the user. The item's **index** is passed.
        """
        ...

    @property
    def textActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcombobox.html#textActivated

        **[signal, since 5.14] void QComboBox::textActivated(const QString &
        text )**

        This signal is sent when the user chooses an item in the combobox. The
        item's **text** is passed. Note that this signal is sent even when the
        choice is not changed. If you need to know when the choice actually
        changes, use signal **currentIndexChanged** () or **currentTextChanged**
        ().

        This function was introduced in Qt 5.14.
        """
        ...

    @property
    def textHighlighted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcombobox.html#textHighlighted

        **[signal, since 5.14] void QComboBox::textHighlighted(const QString &
        text )**

        This signal is sent when an item in the combobox popup list is
        highlighted by the user. The item's **text** is passed.

        This function was introduced in Qt 5.14.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QQuickRenderTarget(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qquickrendertarget.html

    **Detailed Description**

    **See also** **QQuickWindow::setRenderTarget** () and
    **QQuickGraphicsDevice** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickrendertarget.html#QQuickRenderTarget

        **QQuickRenderTarget::QQuickRenderTarget()**

        Constructs a default QQuickRenderTarget that does not reference any
        native objects.
        """
        ...

    @typing.overload
    def __init__(self, other: "QQuickRenderTarget") -> None:
        """
        https://doc.qt.io/qt-6/qquickrendertarget.html#QQuickRenderTarget

        **QQuickRenderTarget::QQuickRenderTarget()**

        Constructs a default QQuickRenderTarget that does not reference any
        native objects.
        """
        ...

    @staticmethod
    def fromOpenGLRenderBuffer(
        renderbufferId: int, pixelSize: QtCore.QSize, sampleCount: int = ...
    ) -> "QQuickRenderTarget":
        """
        https://doc.qt.io/qt-6/qquickrendertarget.html#fromOpenGLRenderBuffer

        **[static, since 6.2] QQuickRenderTarget
        QQuickRenderTarget::fromOpenGLRenderBuffer(uint renderbufferId , const
        QSize & pixelSize , int sampleCount = 1)**

        Returns a new **QQuickRenderTarget**  referencing an OpenGL renderbuffer
        object specified by **renderbufferId**.

        The renderbuffer will be used as the color attachment for the internal
        framebuffer object. This function is provided to allow targeting
        renderbuffers that are created by the application with some external
        buffer underneath, such as an EGLImageKHR. Once the application has
        called **glEGLImageTargetRenderbufferStorageOES** , the renderbuffer can
        be passed to this function.

        **pixelSize** specifies the size of the image, in pixels.

        **sampleCount** specific the number of samples. 0 or 1 means no
        multisampling, while a value like 4 or 8 states that the native object
        is a multisample renderbuffer.

        **Note:** the resulting **QQuickRenderTarget**  does not own any native
        resources, it merely contains references and the associated metadata of
        the size and sample count. It is the caller's responsibility to ensure
        that the native resource exists as long as necessary.

        This function was introduced in Qt 6.2.

        **See also** **QQuickWindow::setRenderTarget** () and
        **QQuickRenderControl** .
        """
        ...

    @staticmethod
    def fromOpenGLTexture(
        textureId: int, pixelSize: QtCore.QSize, sampleCount: int = ...
    ) -> "QQuickRenderTarget":
        """
        https://doc.qt.io/qt-6/qquickrendertarget.html#fromOpenGLTexture

        **[static] QQuickRenderTarget QQuickRenderTarget::fromOpenGLTexture(uint
        textureId , const QSize & pixelSize , int sampleCount = 1)**

        Returns a new **QQuickRenderTarget**  referencing an OpenGL texture
        object specified by **textureId**.

        **pixelSize** specifies the size of the image, in pixels. Currently only
        2D textures are supported.

        **sampleCount** specific the number of samples. 0 or 1 means no
        multisampling, while a value like 4 or 8 states that the native object
        is a multisample texture.

        **Note:** the resulting **QQuickRenderTarget**  does not own any native
        resources, it merely contains references and the associated metadata of
        the size and sample count. It is the caller's responsibility to ensure
        that the native resource exists as long as necessary.

        **See also** **QQuickWindow::setRenderTarget** () and
        **QQuickRenderControl** .
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickrendertarget.html#isNull

        **bool QQuickRenderTarget::isNull() const**

        Returns true if this **QQuickRenderTarget**  is default constructed,
        referencing no native objects.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QElapsedTimer(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qelapsedtimer.html

    **Detailed Description**

    The QElapsedTimer class is usually used to quickly calculate how much time
    has elapsed between two events. Its API is similar to that of **QTime** , so
    code that was using that can be ported quickly to the new class.

    However, unlike **QTime** , QElapsedTimer tries to use monotonic clocks if
    possible. This means it's not possible to convert QElapsedTimer objects to a
    human-readable time.

    The typical use-case for the class is to determine how much time was spent
    in a slow operation. The simplest example of such a case is for debugging
    purposes, as in the following example:

    **QElapsedTimer**  timer;
            timer.start();
    slowOperation1();

            **qDebug** () << "The slow operation took" <<
    timer.elapsed() << "milliseconds";

    In this example, the timer is started by a call to **start** () and the
    elapsed time is calculated by the **elapsed** () function.

    The time elapsed can also be used to recalculate the time available for
    another operation, after the first one is complete. This is useful when the
    execution must complete within a certain time period, but several steps are
    needed. The `waitFor`-type functions in **QIODevice**  and its subclasses
    are good examples of such need. In that case, the code could be as follows:

    void executeSlowOperations(int timeout)
        {
            **QElapsedTimer**
    timer;
            timer.start();
            slowOperation1();

            int
    remainingTime = timeout - timer.elapsed();
            if (remainingTime > 0)
    slowOperation2(remainingTime);
        }

    Another use-case is to execute a certain operation for a specific timeslice.
    For this, QElapsedTimer provides the **hasExpired** () convenience function,
    which can be used to determine if a certain number of milliseconds has
    already elapsed:

    void executeOperationsForTime(int ms)
        {
            **QElapsedTimer**
    timer;
            timer.start();

            while (!timer.hasExpired(ms))
    slowOperation1();
        }

    It is often more convenient to use **QDeadlineTimer**  in this case, which
    counts towards a timeout in the future instead of tracking elapsed time.

    **Reference Clocks**

    QElapsedTimer will use the platform's monotonic reference clock in all
    platforms that support it (see **QElapsedTimer::isMonotonic** ()). This has
    the added benefit that QElapsedTimer is immune to time adjustments, such as
    the user correcting the time. Also unlike **QTime** , QElapsedTimer is
    immune to changes in the timezone settings, such as daylight-saving periods.

    On the other hand, this means QElapsedTimer values can only be compared with
    other values that use the same reference. This is especially true if the
    time since the reference is extracted from the QElapsedTimer object
    (**QElapsedTimer::msecsSinceReference** ()) and serialised. These values
    should never be exchanged across the network or saved to disk, since there's
    no telling whether the computer node receiving the data is the same as the
    one originating it or if it has rebooted since.

    It is, however, possible to exchange the value with other processes running
    on the same machine, provided that they also use the same reference clock.
    QElapsedTimer will always use the same clock, so it's safe to compare with
    the value coming from another process in the same machine. If comparing to
    values produced by other APIs, you should check that the clock used is the
    same as QElapsedTimer (see **QElapsedTimer::clockType** ()).

    **32-bit overflows**

    Some of the clocks used by QElapsedTimer have a limited range and may
    overflow after hitting the upper limit (usually 32-bit). QElapsedTimer deals
    with this overflow issue and presents a consistent timing. However, when
    extracting the time since reference from QElapsedTimer, two different
    processes in the same machine may have different understanding of how much
    time has actually elapsed.

    The information on which clocks types may overflow and how to remedy that
    issue is documented along with the clock types.

    **See also** **QTime** , **QTimer** , and **QDeadlineTimer** .
    """

    class ClockType(enum.Enum):
        SystemTime: QElapsedTimer = ...
        MonotonicClock: QElapsedTimer = ...
        TickCounter: QElapsedTimer = ...
        MachAbsoluteTime: QElapsedTimer = ...
        PerformanceCounter: QElapsedTimer = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#QElapsedTimer

        **[since 5.4] QElapsedTimer::QElapsedTimer()**

        Constructs an invalid QElapsedTimer. A timer becomes valid once it has
        been started.

        This function was introduced in Qt 5.4.

        **See also** **isValid** () and **start** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QElapsedTimer") -> None:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#QElapsedTimer

        **[since 5.4] QElapsedTimer::QElapsedTimer()**

        Constructs an invalid QElapsedTimer. A timer becomes valid once it has
        been started.

        This function was introduced in Qt 5.4.

        **See also** **isValid** () and **start** ().
        """
        ...

    def nsecsElapsed(self) -> int:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#nsecsElapsed

        **qint64 QElapsedTimer::nsecsElapsed() const**

        Returns the number of nanoseconds since this **QElapsedTimer**  was last
        started.

        Calling this function on a **QElapsedTimer**  that is invalid results in
        undefined behavior.

        On platforms that do not provide nanosecond resolution, the value
        returned will be the best estimate available.

        **See also** **start** (), **restart** (), **hasExpired** (), and
        **invalidate** ().
        """
        ...

    def secsTo(self, other: "QElapsedTimer") -> int:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#secsTo

        **qint64 QElapsedTimer::secsTo(const QElapsedTimer & other ) const**

        Returns the number of seconds between this **QElapsedTimer**  and
        **other**. If **other** was started before this object, the returned
        value will be negative. If it was started later, the returned value will
        be positive.

        Calling this function on or with a **QElapsedTimer**  that is invalid
        results in undefined behavior.

        **See also** **msecsTo** () and **elapsed** ().
        """
        ...

    def msecsTo(self, other: "QElapsedTimer") -> int:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#msecsTo

        **qint64 QElapsedTimer::msecsTo(const QElapsedTimer & other ) const**

        Returns the number of milliseconds between this **QElapsedTimer**  and
        **other**. If **other** was started before this object, the returned
        value will be negative. If it was started later, the returned value will
        be positive.

        The return value is undefined if this object or **other** were
        invalidated.

        **See also** **secsTo** () and **elapsed** ().
        """
        ...

    def msecsSinceReference(self) -> int:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#msecsSinceReference

        **qint64 QElapsedTimer::msecsSinceReference() const**

        Returns the number of milliseconds between last time this
        **QElapsedTimer**  object was started and its reference clock's start.

        This number is usually arbitrary for all clocks except the
        **QElapsedTimer::SystemTime**  clock. For that clock type, this number
        is the number of milliseconds since January 1st, 1970 at 0:00 UTC (that
        is, it is the Unix time expressed in milliseconds).

        On Linux, Windows and Apple platforms, this value is usually the time
        since the system boot, though it usually does not include the time the
        system has spent in sleep states.

        **See also** **clockType** () and **elapsed** ().
        """
        ...

    def hasExpired(self, timeout: int) -> bool:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#hasExpired

        **bool QElapsedTimer::hasExpired(qint64 timeout ) const**

        Returns `true` if this **QElapsedTimer**  has already expired by
        **timeout** milliseconds (that is, more than **timeout** milliseconds
        have elapsed). The value of **timeout** can be -1 to indicate that this
        timer does not expire, in which case this function will always return
        false.

        **See also** **elapsed** () and **QDeadlineTimer** .
        """
        ...

    def elapsed(self) -> int:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#elapsed

        **qint64 QElapsedTimer::elapsed() const**

        Returns the number of milliseconds since this **QElapsedTimer**  was
        last started.

        Calling this function on a **QElapsedTimer**  that is invalid results in
        undefined behavior.

        **See also** **start** (), **restart** (), **hasExpired** (),
        **isValid** (), and **invalidate** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#isValid

        **bool QElapsedTimer::isValid() const**

        Returns `false` if the timer has never been started or invalidated by a
        call to **invalidate** ().

        **See also** **invalidate** (), **start** (), and **restart** ().
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#invalidate

        **void QElapsedTimer::invalidate()**

        Marks this **QElapsedTimer**  object as invalid.

        An invalid object can be checked with **isValid** (). Calculations of
        timer elapsed since invalid data are undefined and will likely produce
        bizarre results.

        **See also** **isValid** (), **start** (), and **restart** ().
        """
        ...

    def restart(self) -> int:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#restart

        **qint64 QElapsedTimer::restart()**

        Restarts the timer and returns the number of milliseconds elapsed since
        the previous start. This function is equivalent to obtaining the elapsed
        time with **elapsed** () and then starting the timer again with
        **start** (), but it does so in one single operation, avoiding the need
        to obtain the clock value twice.

        Calling this function on a **QElapsedTimer**  that is invalid results in
        undefined behavior.

        The following example illustrates how to use this function to calibrate
        a parameter to a slow operation (for example, an iteration count) so
        that this operation takes at least 250 milliseconds:

        **QElapsedTimer**  timer;

                int count = 1;
        timer.start();
                do {
                    count *= 2;
        slowOperation2(count);
                } while (timer.restart() < 250);
        return count;

        **See also** **start** (), **invalidate** (), **elapsed** (), and
        **isValid** ().
        """
        ...

    def start(self) -> None:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#start

        **void QElapsedTimer::start()**

        Starts this timer. Once started, a timer value can be checked with
        **elapsed** () or **msecsSinceReference** ().

        Normally, a timer is started just before a lengthy operation, such as:

        **QElapsedTimer**  timer;
                timer.start();
        slowOperation1();

                **qDebug** () << "The slow operation
        took" << timer.elapsed() << "milliseconds";

        Also, starting a timer makes it valid again.

        **See also** **restart** (), **invalidate** (), and **elapsed** ().
        """
        ...

    @staticmethod
    def isMonotonic() -> bool:
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#isMonotonic

        **[static] bool QElapsedTimer::isMonotonic()**

        Returns `true` if this is a monotonic clock, false otherwise. See the
        information on the different clock types to understand which ones are
        monotonic.

        **See also** **clockType** () and **QElapsedTimer::ClockType** .
        """
        ...

    @staticmethod
    def clockType() -> "QElapsedTimer.ClockType":
        """
        https://doc.qt.io/qt-6/qelapsedtimer.html#clockType

        **[static] QElapsedTimer::ClockType QElapsedTimer::clockType()**

        Returns the clock type that this **QElapsedTimer**  implementation uses.

        **See also** **isMonotonic** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QMarginsF(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmarginsf.html

    **Detailed Description**

    QMarginsF defines a set of four margins; left, top, right, and bottom, that
    describe the finite size of the borders surrounding a rectangle.

    The **isNull** () function returns `true` only if all margins are very close
    to zero.

    QMarginsF objects can be streamed as well as compared.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#QMarginsF

        **QMarginsF::QMarginsF()**

        Constructs a margins object with all margins set to 0.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(
        self, aleft: float, atop: float, aright: float, abottom: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#QMarginsF-1

        **QMarginsF::QMarginsF(qreal left , qreal top , qreal right , qreal
        bottom )**

        Constructs margins with the given **left** , **top** , **right** , and
        **bottom**. All parameters must be finite.

        **See also** **setLeft** (), **setRight** (), **setTop** (), and
        **setBottom** ().
        """
        ...

    @typing.overload
    def __init__(self, margins: QMargins) -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#QMarginsF-2

        **QMarginsF::QMarginsF(const QMargins & margins )**

        Constructs margins copied from the given **margins**
        """
        ...

    @typing.overload
    def __init__(self, a0: "QMarginsF") -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#QMarginsF

        **QMarginsF::QMarginsF()**

        Constructs a margins object with all margins set to 0.

        **See also** **isNull** ().
        """
        ...

    def __pos__(self) -> "QMarginsF":
        ...

    def __neg__(self) -> "QMarginsF":
        ...

    def toMargins(self) -> QMargins:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#toMargins

        **QMargins QMarginsF::toMargins() const**

        Returns an integer-based copy of this margins object.

        Note that the components in the returned margins will be rounded to the
        nearest integer.

        **See also** **QMarginsF** ().
        """
        ...

    def setBottom(self, abottom: float) -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#setBottom

        **void QMarginsF::setBottom(qreal abottom )**

        Sets the bottom margin to **abottom** (which must be finite).

        **See also** **bottom** ().
        """
        ...

    def setRight(self, aright: float) -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#setRight

        **void QMarginsF::setRight(qreal aright )**

        Sets the right margin to **aright** (which must be finite).

        **See also** **right** ().
        """
        ...

    def setTop(self, atop: float) -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#setTop

        **void QMarginsF::setTop(qreal atop )**

        Sets the top margin to **atop** (which must be finite).

        **See also** **top** ().
        """
        ...

    def setLeft(self, aleft: float) -> None:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#setLeft

        **void QMarginsF::setLeft(qreal aleft )**

        Sets the left margin to **aleft** (which must be finite).

        **See also** **left** ().
        """
        ...

    def bottom(self) -> float:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#bottom

        **qreal QMarginsF::bottom() const**

        Returns the bottom margin.

        **See also** **setBottom** ().
        """
        ...

    def right(self) -> float:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#right

        **qreal QMarginsF::right() const**

        Returns the right margin.

        **See also** **setRight** ().
        """
        ...

    def top(self) -> float:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#top

        **qreal QMarginsF::top() const**

        Returns the top margin.

        **See also** **setTop** ().
        """
        ...

    def left(self) -> float:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#left

        **qreal QMarginsF::left() const**

        Returns the left margin.

        **See also** **setLeft** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmarginsf.html#isNull

        **bool QMarginsF::isNull() const**

        Returns `true` if all margins are very close to 0; otherwise returns
        false.

        **See also** **qFuzzyIsNull** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtPositioning import *


class QGeoPath(QGeoShape):
    """
    https://doc.qt.io/qt-6/qgeopath.html

    **Detailed Description**

    The path is defined by an ordered list of **QGeoCoordinate**  objects.

    Each two adjacent elements in the path are intended to be connected together
    by the shortest line segment of constant bearing passing through both
    elements. This type of connection can cross the dateline in the longitudinal
    direction, but never crosses the poles.

    This is relevant for the calculation of the bounding box returned by
    **QGeoShape::boundingGeoRectangle** () for this shape, which will have the
    latitude of the top left corner set to the maximum latitude in the path
    point set. Similarly, the latitude of the bottom right corner will be the
    minimum latitude in the path point set.

    This class is a **Q_GADGET** . It can be **directly used from C++ and QML**
    .

    A QGeoPath is both invalid and empty if it contains no coordinate.

    **Note:** A default constructed QGeoPath is both invalid and empty as it
    does not contain any coordinates.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#QGeoPath

        **QGeoPath::QGeoPath()**

        Constructs a new, empty geo path.
        """
        ...

    @typing.overload
    def __init__(
        self, path: typing.Iterable[QGeoCoordinate], width: float = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#QGeoPath-1

        **QGeoPath::QGeoPath(const QList<QGeoCoordinate> & path , const qreal &
        width = 0.0)**

        Constructs a new geo path from a list of coordinates ( **path** and
        **width** ).
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoPath") -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#QGeoPath-2

        **QGeoPath::QGeoPath(const QGeoPath & other )**

        Constructs a new geo path from the contents of **other**.
        """
        ...

    @typing.overload
    def __init__(self, other: QGeoShape) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#QGeoPath-3

        **QGeoPath::QGeoPath(const QGeoShape & other )**

        Constructs a new geo path from the contents of **other**.
        """
        ...

    def clearPath(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#clearPath

        **[since 5.12] void QGeoPath::clearPath()**

        Clears the path.

        This function was introduced in Qt 5.12.
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeopath.html#size

        **[invokable, since 5.10] qsizetype QGeoPath::size() const**

        Returns the number of elements in the path.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.10.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeopath.html#toString

        **[invokable] QString QGeoPath::toString() const**

        Returns the geo path properties as a string.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @typing.overload
    def removeCoordinate(self, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#removeCoordinate

        **[invokable] void QGeoPath::removeCoordinate(const QGeoCoordinate &
        coordinate )**

        Removes the last occurrence of **coordinate** from the path.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @typing.overload
    def removeCoordinate(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#removeCoordinate-1

        **[invokable] void QGeoPath::removeCoordinate(qsizetype index )**

        Removes element at position **index** from the path.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def containsCoordinate(self, coordinate: QGeoCoordinate) -> bool:
        """
        https://doc.qt.io/qt-6/qgeopath.html#containsCoordinate

        **[invokable] bool QGeoPath::containsCoordinate(const QGeoCoordinate &
        coordinate ) const**

        Returns true if the path contains **coordinate** as one of the elements.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def coordinateAt(self, index: int) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeopath.html#coordinateAt

        **[invokable] QGeoCoordinate QGeoPath::coordinateAt(qsizetype index )
        const**

        Returns the coordinate at **index** .

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def replaceCoordinate(self, index: int, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#replaceCoordinate

        **[invokable] void QGeoPath::replaceCoordinate(qsizetype index , const
        QGeoCoordinate & coordinate )**

        Replaces the path element at the specified **index** with
        **coordinate**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def insertCoordinate(self, index: int, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#insertCoordinate

        **[invokable] void QGeoPath::insertCoordinate(qsizetype index , const
        QGeoCoordinate & coordinate )**

        Inserts **coordinate** at the specified **index**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def addCoordinate(self, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#addCoordinate

        **[invokable] void QGeoPath::addCoordinate(const QGeoCoordinate &
        coordinate )**

        Appends **coordinate** to the path.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def length(self, indexFrom: int = ..., indexTo: int = ...) -> float:
        """
        https://doc.qt.io/qt-6/qgeopath.html#length

        **[invokable] double QGeoPath::length(qsizetype indexFrom = 0, qsizetype
        indexTo = -1) const**

        Returns the length of the path, in meters, from the element
        **indexFrom** to the element **indexTo**. The length is intended to be
        the sum of the shortest distances for each pair of adjacent points.

        If **indexTo** is -1 (the default value), the length will be including
        the distance between last coordinate and the first (closed loop). To
        retrieve the length for the path, use 0 for **indexFrom** and
        **QGeoPath::size** () - 1 for **indexTo**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def translated(self, degreesLatitude: float, degreesLongitude: float) -> "QGeoPath":
        """
        https://doc.qt.io/qt-6/qgeopath.html#translated

        **[invokable] QGeoPath QGeoPath::translated(double degreesLatitude ,
        double degreesLongitude ) const**

        Returns a copy of this geo path translated by **degreesLatitude**
        northwards and **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **translate** ().
        """
        ...

    def translate(self, degreesLatitude: float, degreesLongitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#translate

        **[invokable] void QGeoPath::translate(double degreesLatitude , double
        degreesLongitude )**

        Translates this geo path by **degreesLatitude** northwards and
        **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qgeopath.html#width

        **qreal QGeoPath::width() const**

        Returns the width of the path, in meters. This information is used in
        the **contains**  method. The default value is 0.

        **Note:** Getter function for property **width** .

        **See also** **setWidth** ().
        """
        ...

    def setWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#width-prop

        **width : qreal**

        This property holds the width of the path in meters.

        **Access functions:**

        qreal ****width** ** () const
        void **setWidth** (const qreal &
        **width** )

        **Member Function Documentation**
        """
        ...

    def path(self) -> typing.List[QGeoCoordinate]:
        """
        https://doc.qt.io/qt-6/qgeopath.html#path

        **const QList<QGeoCoordinate> &QGeoPath::path() const**

        Returns all the elements of the path.

        **See also** **setPath** ().
        """
        ...

    def setPath(self, path: typing.Iterable[QGeoCoordinate]) -> None:
        """
        https://doc.qt.io/qt-6/qgeopath.html#setPath

        **void QGeoPath::setPath(const QList<QGeoCoordinate> & path )**

        Sets all the elements of the **path**.

        **See also** **path** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import SIP_VERSION as SIP_VERSION
from ._functions import SIP_VERSION_STR as SIP_VERSION_STR
from ._functions import T as T
from ._functions import Buffer as Buffer
from ._functions import assign as assign
from ._functions import cast as cast
from ._functions import delete as delete
from ._functions import dump as dump
from ._functions import enableautoconversion as enableautoconversion
from ._functions import isdeleted as isdeleted
from ._functions import ispycreated as ispycreated
from ._functions import ispyowned as ispyowned
from ._functions import setdeleted as setdeleted
from ._functions import settracemask as settracemask
from ._functions import transferback as transferback
from ._functions import transferto as transferto
from ._functions import unwrapinstance as unwrapinstance
from ._functions import wrapinstance as wrapinstance
from ._wrappertype import wrappertype as wrappertype
from ._simplewrapper import simplewrapper as simplewrapper
from ._wrapper import wrapper as wrapper
from ._array import array as array
from ._voidptr import voidptr as voidptr



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui


class QQuickGraphicsDevice(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qquickgraphicsdevice.html

    **Detailed Description**

    **See also** **QQuickWindow::setGraphicsDevice** () and
    **QQuickRenderTarget** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#QQuickGraphicsDevice

        **QQuickGraphicsDevice::QQuickGraphicsDevice()**

        Constructs a default QQuickGraphicsDevice that does not reference any
        native objects.
        """
        ...

    @typing.overload
    def __init__(self, other: "QQuickGraphicsDevice") -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#QQuickGraphicsDevice

        **QQuickGraphicsDevice::QQuickGraphicsDevice()**

        Constructs a default QQuickGraphicsDevice that does not reference any
        native objects.
        """
        ...

    @staticmethod
    def fromOpenGLContext(context: QtGui.QOpenGLContext) -> "QQuickGraphicsDevice":
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#fromOpenGLContext

        **[static] QQuickGraphicsDevice
        QQuickGraphicsDevice::fromOpenGLContext(QOpenGLContext * context )**

        Returns a new **QQuickGraphicsDevice**  referencing an existing OpenGL
        **context**.

        This factory function is suitable for OpenGL.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#isNull

        **bool QQuickGraphicsDevice::isNull() const**

        Returns true if this is a default constructed graphics device that does
        not reference any native objects.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QScrollArea(QAbstractScrollArea):
    """
    https://doc.qt.io/qt-6/qscrollarea.html

    **Detailed Description**

    A scroll area is used to display the contents of a child widget within a
    frame. If the widget exceeds the size of the frame, the view can provide
    scroll bars so that the entire area of the child widget can be viewed. The
    child widget must be specified with **setWidget** (). For example:

    **QLabel**  *imageLabel = new **QLabel** ;
        **QImage**
    image("happyguy.png");
        imageLabel->setPixmap(**QPixmap**
    ::fromImage(image));

        scrollArea = new **QScrollArea** ;
    scrollArea->setBackgroundRole(**QPalette** ::Dark);
    scrollArea->setWidget(imageLabel);

    The code above creates a scroll area (shown in the images below) containing
    an image label. When scaling the image, the scroll area can provide the
    necessary scroll bars:

    ![](images/qscrollarea-noscrollbars.png)![](images/qscrollarea-
    onescrollbar.png)![](images/qscrollarea-twoscrollbars.png)

    The scroll bars appearance depends on the currently set **scroll bar
    policies** . You can control the appearance of the scroll bars using the
    inherited functionality from **QAbstractScrollArea** .

    For example, you can set the
    **QAbstractScrollArea::horizontalScrollBarPolicy**  and
    **QAbstractScrollArea::verticalScrollBarPolicy**  properties. Or if you want
    the scroll bars to adjust dynamically when the contents of the scroll area
    changes, you can use the **horizontalScrollBar** () and
    **verticalScrollBar** () functions (which enable you to access the scroll
    bars) and set the scroll bars' values whenever the scroll area's contents
    change, using the **QScrollBar::setValue** () function.

    You can retrieve the child widget using the **widget** () function. The view
    can be made to be resizable with the **setWidgetResizable** () function. The
    alignment of the widget can be specified with **setAlignment** ().

    Two convenience functions **ensureVisible** () and **ensureWidgetVisible**
    () ensure a certain region of the contents is visible inside the viewport,
    by scrolling the contents if necessary.

    **Size Hints and Layouts**

    When using a scroll area to display the contents of a custom widget, it is
    important to ensure that the **size hint**  of the child widget is set to a
    suitable value. If a standard **QWidget**  is used for the child widget, it
    may be necessary to call **QWidget::setMinimumSize** () to ensure that the
    contents of the widget are shown correctly within the scroll area.

    If a scroll area is used to display the contents of a widget that contains
    child widgets arranged in a layout, it is important to realize that the size
    policy of the layout will also determine the size of the widget. This is
    especially useful to know if you intend to dynamically change the contents
    of the layout. In such cases, setting the layout's **size constraint**
    property to one which provides constraints on the minimum and/or maximum
    size of the layout (e.g., **QLayout::SetMinAndMaxSize** ) will cause the
    size of the scroll area to be updated whenever the contents of the layout
    changes.

    For a complete example using the QScrollArea class, see the **Image Viewer**
    example. The example shows how to combine **QLabel**  and QScrollArea to
    display an image.

    **See also** **QAbstractScrollArea** , **QScrollBar** , and **Image Viewer
    Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#QScrollArea

        **QScrollArea::QScrollArea(QWidget * parent = nullptr)**

        Constructs an empty scroll area with the given **parent**.

        **See also** **setWidget** ().
        """
        ...

    def viewportSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#viewportSizeHint

        **[override virtual protected] QSize QScrollArea::viewportSizeHint()
        const**

        Reimplements: **QAbstractScrollArea::viewportSizeHint() const** .
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#scrollContentsBy

        **[override virtual protected] void QScrollArea::scrollContentsBy(int dx
        , int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#resizeEvent

        **[override virtual protected] void
        QScrollArea::resizeEvent(QResizeEvent *)**

        Reimplements: **QAbstractScrollArea::resizeEvent** (QResizeEvent
        *event).
        """
        ...

    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#eventFilter

        **[override virtual protected] bool QScrollArea::eventFilter(QObject * o
        , QEvent * e )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#event

        **[override virtual protected] bool QScrollArea::event(QEvent * e )**

        Reimplements: **QAbstractScrollArea::event** (QEvent *event).
        """
        ...

    def ensureWidgetVisible(
        self, childWidget: QWidget, xMargin: int = ..., yMargin: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#ensureWidgetVisible

        **void QScrollArea::ensureWidgetVisible(QWidget * childWidget , int
        xmargin = 50, int ymargin = 50)**

        Scrolls the contents of the scroll area so that the **childWidget** of
        **QScrollArea::widget** () is visible inside the viewport with margins
        specified in pixels by **xmargin** and **ymargin**. If the specified
        point cannot be reached, the contents are scrolled to the nearest valid
        position. The default value for both margins is 50 pixels.
        """
        ...

    def ensureVisible(
        self, x: int, y: int, xMargin: int = ..., yMargin: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#ensureVisible

        **void QScrollArea::ensureVisible(int x , int y , int xmargin = 50, int
        ymargin = 50)**

        Scrolls the contents of the scroll area so that the point ( **x** ,
        **y** ) is visible inside the region of the viewport with margins
        specified in pixels by **xmargin** and **ymargin**. If the specified
        point cannot be reached, the contents are scrolled to the nearest valid
        position. The default value for both margins is 50 pixels.
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#focusNextPrevChild

        **[override virtual] bool QScrollArea::focusNextPrevChild(bool next )**

        Reimplements: **QWidget::focusNextPrevChild** (bool next).
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#sizeHint

        **[override virtual] QSize QScrollArea::sizeHint() const**

        Reimplements: **QAbstractScrollArea::sizeHint() const** .
        """
        ...

    def setAlignment(self, a0: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the scroll area's widget

        A valid alignment is a combination of the following flags:

        * `Qt::AlignLeft`
          * `Qt::AlignHCenter`
          * `Qt::AlignRight`
          *
        `Qt::AlignTop`
          * `Qt::AlignVCenter`
          * `Qt::AlignBottom`

        By default, the widget stays rooted to the top-left corner of the scroll
        area.

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment)
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the scroll area's widget

        A valid alignment is a combination of the following flags:

        * `Qt::AlignLeft`
          * `Qt::AlignHCenter`
          * `Qt::AlignRight`
          *
        `Qt::AlignTop`
          * `Qt::AlignVCenter`
          * `Qt::AlignBottom`

        By default, the widget stays rooted to the top-left corner of the scroll
        area.

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment)
        """
        ...

    def setWidgetResizable(self, resizable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#widgetResizable-prop

        **widgetResizable : bool**

        This property holds whether the scroll area should resize the view
        widget

        If this property is set to false (the default), the scroll area honors
        the size of its widget. Regardless of this property, you can
        programmatically resize the widget using **widget** ()->**resize** (),
        and the scroll area will automatically adjust itself to the new size.

        If this property is set to true, the scroll area will automatically
        resize the widget in order to avoid scroll bars where they can be
        avoided, or to take advantage of extra space.

        **Access functions:**

        bool **widgetResizable** () const
        void **setWidgetResizable** (bool
        **resizable** )

        **Member Function Documentation**
        """
        ...

    def widgetResizable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#widgetResizable-prop

        **widgetResizable : bool**

        This property holds whether the scroll area should resize the view
        widget

        If this property is set to false (the default), the scroll area honors
        the size of its widget. Regardless of this property, you can
        programmatically resize the widget using **widget** ()->**resize** (),
        and the scroll area will automatically adjust itself to the new size.

        If this property is set to true, the scroll area will automatically
        resize the widget in order to avoid scroll bars where they can be
        avoided, or to take advantage of extra space.

        **Access functions:**

        bool **widgetResizable** () const
        void **setWidgetResizable** (bool
        **resizable** )

        **Member Function Documentation**
        """
        ...

    def takeWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#takeWidget

        **QWidget *QScrollArea::takeWidget()**

        Removes the scroll area's widget, and passes ownership of the widget to
        the caller.

        **See also** **widget** ().
        """
        ...

    def setWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#setWidget

        **void QScrollArea::setWidget(QWidget * widget )**

        Sets the scroll area's **widget**.

        The **widget** becomes a child of the scroll area, and will be destroyed
        when the scroll area is deleted or when a new widget is set.

        The widget's **autoFillBackground**  property will be set to `true`.

        If the scroll area is visible when the **widget** is added, you must
        **show** () it explicitly.

        Note that You must add the layout of **widget** before you call this
        function; if you add it later, the **widget** will not be visible -
        regardless of when you **show** () the scroll area. In this case, you
        can also not **show** () the **widget** later.

        **See also** **widget** ().
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qscrollarea.html#widget

        **QWidget *QScrollArea::widget() const**

        Returns the scroll area's widget, or `nullptr` if there is none.

        **See also** **setWidget** ().
        """
        ...
